<?php
/*
Plugin Name: Alvaro - Custom Post Types
Version: 1.0
Description: Add specific custom post types for Alvaro Theme
Author: AA-Team
Plugin URI: http://themeforest.net/user/AA-Team/portfolio
*/

if(class_exists('alvaroPostTypes') != true) {
	class alvaroPostTypes
	{
		public $the_theme = null;
		public $data = array();
		public $settings = array();
		public $alias = 'alvaro';

		// shortcuts
		public $locName = '';

		/* 1. The class constructor
		=========================== */
		public function __construct( $the_theme=array() )
		{
			// dietitians custom post type
			add_action( 'init', array($this, 'init') );
			
			add_image_size( 'fish-thumb-admin', 80, 123, false );
			
			$this->load_theme_widgets();
			
			// change the layout of partners list
			add_filter('manage_edit-fish_species_columns', array( $this, 'alvaroFishSpecies_edit_columns' ) );
			add_action('manage_posts_custom_column', array( $this, 'alvaroFishSpecies_posts_columns' ), 10, 2);
			
			add_action( 'add_meta_boxes', array( $this, 'page_layout_metabox' ) );
			add_action( 'save_post', array( $this, 'page_layout_save_meta_box_data' ) );
			
		}
		
		public function init()
		{
			$this->alvaroFishSpecies();
			$this->alvaroTestimonials();
			$this->alvaroCampingLocations();
			$this->WooSidebarsInit();
			
			add_shortcode('alvaro_social_share', array($this, 'alvaro_social_share'));
		}

		public function load_theme_widgets()
		{
			$widgets_folder = array_filter( glob( plugin_dir_path(__FILE__) . '/widgets/*' ), 'is_dir' );  
			if( count($widgets_folder) > 0 ){
				foreach ($widgets_folder as $widget) {
					if( file_exists( $widget . '/widget.class.php' ) ){
						require_once( $widget . '/widget.class.php' );
					}
				}
			}
		}

		public function WooSidebarsInit()
		{
			// if woo sidebars installed add meta box
			if( class_exists( 'Woo_Sidebars' ) === true ){ 
				add_action( 'add_meta_boxes', array( $this, 'woosidebar_metabox' ) );
				add_action( 'save_post', array( $this, 'woosidebar_metabox_save' ) );
			}
		}
		
		public function woosidebar_metabox( $post_type )
		{
			if( $post_type != "sidebar" ) return false;

			add_meta_box(
				'sidebar-position-meta-box',
				esc_html__( 'Sidebar Position', 'alvaro' ),
				array( $this, 'sidebar_position_box' ),
				$post_type,
				'advanced',
				'high'
			);
		}

		public function woosidebar_metabox_save( $post_id )
		{
			global $post;
			if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
				return;
			}
			if ( isset( $_POST['post_type'] ) && 'sidebar' == $_POST['post_type'] ) {
				$pos = isset($_POST['we-checkbox-pos']) ? $_POST['we-checkbox-pos'] : '';

				update_post_meta( $post_id, "_alvaro_sidebar_position", $pos );
			}
		}
		
		public function sidebar_position_box()
		{
			global $post;
			$html = array();

			$post_id = isset($post->ID) ? (int)$post->ID : 0;
			$sidebar_pos = get_post_meta( $post_id, "_alvaro_sidebar_position", true );

			if( !$sidebar_pos ){
				$sidebar_pos = 'left';
			}

			$html[] = '<div class="we-choose-position">';
			$html[] = 	'<a href="#" class="we-choose-left ' . ( $sidebar_pos == 'left' ? 'on' : '' ) . '"><input type="radio" name="we-checkbox-pos" ' . ( $sidebar_pos == 'left' ? 'checked' : '' ) . ' value="left" /></a>';
			$html[] = 	'<a href="#" class="we-choose-right ' . ( $sidebar_pos == 'right' ? 'on' : '' ) . '"><input type="radio" name="we-checkbox-pos" ' . ( $sidebar_pos == 'right' ? 'checked' : '' ) . ' value="right" /></a>';
			$html[] = 	'<a href="#" class="we-choose-none ' . ( $sidebar_pos == 'none' ? 'on' : '' ) . '"><input type="radio" name="we-checkbox-pos" ' . ( $sidebar_pos == 'none' ? 'checked' : '' ) . ' value="none" /></a>';
			$html[] = '</div>';

			echo implode( "\n", $html );
		}

		public function page_layout_metabox()
		{
			add_meta_box(
				$this->alias . 'page_layout',
				esc_html__( 'Page Layout Settings', 'alvaro' ),
				array( $this, 'page_layout_metabox_callback' ),
				'page'
			);
		}

		public function page_layout_metabox_callback()
		{
			global $wpdb, $post;
			$post_id = $post->ID;

			$hide_page_title = get_post_meta( $post_id, '_alvaro_hide_page_title', true );

			$allslides = $wpdb->get_results( "select * from `{$wpdb->prefix}revslider_sliders` where 1=1", ARRAY_A );
			$rev_slider_alias = get_post_meta( $post_id, '_alvaro_rev_slider_alias', true );
		?>
			<div class="alvaro-page-layout">
				<label><input type="checkbox" <?php echo esc_attr($hide_page_title == 'on' ? 'checked' : ''); ?> name="<?php echo esc_attr($this->alias . '_hide_page_title'); ?>"><?php esc_html_e('Hide page title', 'alvaro' )?></label>
				<br />
				<br />
				<label><?php esc_html_e('Full page slider', 'alvaro' )?>: 
					<select name="<?php echo esc_attr($this->alias . '_rev_slider_alias'); ?>">
						<option value="0" <?php echo esc_attr($rev_slider_alias == '0' ? 'selected="selected"' : ''); ?>><?php esc_html_e('None', 'alvaro' )?></option>
						<?php 
						if( count($allslides) > 0 && $allslides ){
							foreach ($allslides as $key => $value) {
								echo '<option ' . ( $rev_slider_alias == $value['alias'] ? 'selected="selected"' : '' ) . ' value="' . ( esc_attr( $value['alias'] ) ) . '">' . ( $value['title'] ) . '</option>';
							}
						}
						?>
					</select>
				</label>
			</div>
		<?php
		}

		public function page_layout_save_meta_box_data( $post_id )
		{
			// If this is an autosave, our form has not been submitted, so we don't want to do anything.
			if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
				return;
			}


			if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {

				if ( ! current_user_can( 'edit_page', $post_id ) ) {
					return;
				}

				update_post_meta( $post_id, '_alvaro_hide_page_title', isset($_REQUEST['alvaro_hide_page_title']) ? $_REQUEST['alvaro_hide_page_title'] : 'off' );

				if( isset($_REQUEST['alvaro_rev_slider_alias']) ) {
					update_post_meta( $post_id, '_alvaro_rev_slider_alias', $_REQUEST['alvaro_rev_slider_alias'] );
				}
			}
		}
		
		public function alvaroFishSpecies() {
			$labels = array(
				'name'                  => _x( 'Fish Species', 'Post Type General Name', 'alvaro' ),
				'singular_name'         => _x( 'Fish', 'Post Type Singular Name', 'alvaro' ),
				'menu_name'             => __( 'Fish Species', 'alvaro' ),
				'name_admin_bar'        => __( 'Fish', 'alvaro' ),
				'archives'              => __( 'Item Archives', 'alvaro' ),
				'attributes'            => __( 'Item Attributes', 'alvaro' ),
				'parent_item_colon'     => __( 'Parent Item:', 'alvaro' ),
				'all_items'             => __( 'All Items', 'alvaro' ),
				'add_new_item'          => __( 'Add New Item', 'alvaro' ),
				'add_new'               => __( 'Add New', 'alvaro' ),
				'new_item'              => __( 'New Item', 'alvaro' ),
				'edit_item'             => __( 'Edit Item', 'alvaro' ),
				'update_item'           => __( 'Update Item', 'alvaro' ),
				'view_item'             => __( 'View Item', 'alvaro' ),
				'view_items'            => __( 'View Items', 'alvaro' ),
				'search_items'          => __( 'Search Item', 'alvaro' ),
				'not_found'             => __( 'Not found', 'alvaro' ),
				'not_found_in_trash'    => __( 'Not found in Trash', 'alvaro' ),
				'featured_image'        => __( 'Featured Image', 'alvaro' ),
				'set_featured_image'    => __( 'Set featured image', 'alvaro' ),
				'remove_featured_image' => __( 'Remove featured image', 'alvaro' ),
				'use_featured_image'    => __( 'Use as featured image', 'alvaro' ),
				'insert_into_item'      => __( 'Insert into item', 'alvaro' ),
				'uploaded_to_this_item' => __( 'Uploaded to this item', 'alvaro' ),
				'items_list'            => __( 'Items list', 'alvaro' ),
				'items_list_navigation' => __( 'Items list navigation', 'alvaro' ),
				'filter_items_list'     => __( 'Filter items list', 'alvaro' ),
			);
			$args = array(
				'label'                 => __( 'Fish', 'alvaro' ),
				'description'           => __( 'Post Type Description', 'alvaro' ),
				'labels'                => $labels,
				'supports'              => array( 'title', 'editor', 'thumbnail', 'excerpt' ),
				'taxonomies'            => array( 'category', 'post_tag' ),
				'hierarchical'          => false,
				'public'                => true,
				'show_ui'               => true,
				'show_in_menu'          => true,
				'menu_position'         => 5,
				'menu_icon'             => 'dashicons-list-view',
				'show_in_admin_bar'     => true,
				'show_in_nav_menus'     => true,
				'can_export'            => true,
				'has_archive'           => true,		
				'exclude_from_search'   => false,
				'publicly_queryable'    => true,
				'capability_type'       => 'page',
			);
			register_post_type( 'fish_species', $args );
		}
		
		public function alvaroFishSpecies_edit_columns($columns) 
		{
		    $new_columns['cb'] 				= '<input type="checkbox" />';
		    $new_columns['fish_species_id'] = __('ID', 'alvaro');
			$new_columns['fish_thumbnail'] 	= __('Image', 'alvaro');
			$new_columns['title'] 			= __('Fish Name', 'alvaro');
		
		    return $new_columns;
		}
		
		public function alvaroFishSpecies_posts_columns($column_name, $id) 
		{
		    global $id; 
			$thumb = get_post_thumbnail_id( $id ); 
		    switch ($column_name) {
				case 'fish_species_id':
		            echo $id;
		            break;
					
		        case 'fish_thumbnail':
					echo wp_get_attachment_image( $thumb, 'fish-thumb-admin' );
		            break;
				
		        default:
		            break;
		    } // end switch
		}

		public function alvaroTestimonials() {
		
			$labels = array(
				'name'                  => _x( 'Testimonials', 'Post Type General Name', 'alvaro' ),
				'singular_name'         => _x( 'Testimonial', 'Post Type Singular Name', 'alvaro' ),
				'menu_name'             => __( 'Testimonials', 'alvaro' ),
				'name_admin_bar'        => __( 'Testimonial', 'alvaro' ),
				'archives'              => __( 'Item Archives', 'alvaro' ),
				'attributes'            => __( 'Item Attributes', 'alvaro' ),
				'parent_item_colon'     => __( 'Parent Item:', 'alvaro' ),
				'all_items'             => __( 'All Items', 'alvaro' ),
				'add_new_item'          => __( 'Add New Item', 'alvaro' ),
				'add_new'               => __( 'Add New', 'alvaro' ),
				'new_item'              => __( 'New Item', 'alvaro' ),
				'edit_item'             => __( 'Edit Item', 'alvaro' ),
				'update_item'           => __( 'Update Item', 'alvaro' ),
				'view_item'             => __( 'View Item', 'alvaro' ),
				'view_items'            => __( 'View Items', 'alvaro' ),
				'search_items'          => __( 'Search Item', 'alvaro' ),
				'not_found'             => __( 'Not found', 'alvaro' ),
				'not_found_in_trash'    => __( 'Not found in Trash', 'alvaro' ),
				'featured_image'        => __( 'Featured Image', 'alvaro' ),
				'set_featured_image'    => __( 'Set featured image', 'alvaro' ),
				'remove_featured_image' => __( 'Remove featured image', 'alvaro' ),
				'use_featured_image'    => __( 'Use as featured image', 'alvaro' ),
				'insert_into_item'      => __( 'Insert into item', 'alvaro' ),
				'uploaded_to_this_item' => __( 'Uploaded to this item', 'alvaro' ),
				'items_list'            => __( 'Items list', 'alvaro' ),
				'items_list_navigation' => __( 'Items list navigation', 'alvaro' ),
				'filter_items_list'     => __( 'Filter items list', 'alvaro' ),
			);
			$args = array(
				'label'                 => __( 'Testimonial', 'alvaro' ),
				'description'           => __( 'Testimonial Description', 'alvaro' ),
				'labels'                => $labels,
				'supports'              => array( 'title', 'editor', ),
				'taxonomies'            => array( 'category', 'post_tag' ),
				'hierarchical'          => false,
				'public'                => true,
				'show_ui'               => true,
				'show_in_menu'          => true,
				'menu_position'         => 5,
				'menu_icon'             => 'dashicons-format-quote',
				'show_in_admin_bar'     => true,
				'show_in_nav_menus'     => true,
				'can_export'            => true,
				'has_archive'           => true,		
				'exclude_from_search'   => false,
				'publicly_queryable'    => true,
				'capability_type'       => 'page',
			);
			register_post_type( 'testimonials', $args );
		
		}		

		// Register Custom Post Type Camping Locations
		public function alvaroCampingLocations() {
		
			$labels = array(
				'name'                  => _x( 'Camping Locations', 'Post Type General Name', 'alvaro' ),
				'singular_name'         => _x( 'Camping', 'Post Type Singular Name', 'alvaro' ),
				'menu_name'             => __( 'Camping Locations', 'alvaro' ),
				'name_admin_bar'        => __( 'Camping Location', 'alvaro' ),
				'archives'              => __( 'Item Archives', 'alvaro' ),
				'attributes'            => __( 'Item Attributes', 'alvaro' ),
				'parent_item_colon'     => __( 'Parent Item:', 'alvaro' ),
				'all_items'             => __( 'All Items', 'alvaro' ),
				'add_new_item'          => __( 'Add New Item', 'alvaro' ),
				'add_new'               => __( 'Add New', 'alvaro' ),
				'new_item'              => __( 'New Item', 'alvaro' ),
				'edit_item'             => __( 'Edit Item', 'alvaro' ),
				'update_item'           => __( 'Update Item', 'alvaro' ),
				'view_item'             => __( 'View Item', 'alvaro' ),
				'view_items'            => __( 'View Items', 'alvaro' ),
				'search_items'          => __( 'Search Item', 'alvaro' ),
				'not_found'             => __( 'Not found', 'alvaro' ),
				'not_found_in_trash'    => __( 'Not found in Trash', 'alvaro' ),
				'featured_image'        => __( 'Featured Image', 'alvaro' ),
				'set_featured_image'    => __( 'Set featured image', 'alvaro' ),
				'remove_featured_image' => __( 'Remove featured image', 'alvaro' ),
				'use_featured_image'    => __( 'Use as featured image', 'alvaro' ),
				'insert_into_item'      => __( 'Insert into item', 'alvaro' ),
				'uploaded_to_this_item' => __( 'Uploaded to this item', 'alvaro' ),
				'items_list'            => __( 'Items list', 'alvaro' ),
				'items_list_navigation' => __( 'Items list navigation', 'alvaro' ),
				'filter_items_list'     => __( 'Filter items list', 'alvaro' ),
			);
			$args = array(
				'label'                 => __( 'Camping', 'alvaro' ),
				'description'           => __( 'Post Type Description', 'alvaro' ),
				'labels'                => $labels,
				'supports'              => array( 'title', 'editor', 'thumbnail' ),
				'taxonomies'            => array( 'category', 'post_tag' ),
				'hierarchical'          => false,
				'public'                => true,
				'show_ui'               => true,
				'show_in_menu'          => true,
				'menu_position'         => 5,
				'menu_icon'             => 'dashicons-location-alt',
				'show_in_admin_bar'     => true,
				'show_in_nav_menus'     => true,
				'can_export'            => true,
				'has_archive'           => true,
				'exclude_from_search'   => false,
				'publicly_queryable'    => true,
				'capability_type'       => 'page',
			);
			register_post_type( 'camping_location', $args );
			
			if( function_exists("register_field_group") )
			{
				register_field_group(array (
					'id' => 'acf_camping-location-options',
					'title' => 'Camping Location Options',
					'fields' => array (
						array (
							'key' => 'field_5a8d5e241c4c1',
							'label' => 'People fish here for',
							'name' => 'people_fish_here_for',
							'type' => 'post_object',
							'post_type' => array (
								0 => 'fish_species',
							),
							'taxonomy' => array (
								0 => 'all',
							),
							'allow_null' => 0,
							'multiple' => 1,
						),
						array (
							'key' => 'field_5a93ed9832d1b',
							'label' => 'Google Maps Embed Code',
							'name' => 'google_maps_embed_code',
							'type' => 'google_map',
							'center_lat' => '',
							'center_lng' => '',
							'zoom' => '',
							'height' => '',
						),
					),
					'location' => array (
						array (
							array (
								'param' => 'post_type',
								'operator' => '==',
								'value' => 'camping_location',
								'order_no' => 0,
								'group_no' => 0,
							),
						),
					),
					'options' => array (
						'position' => 'normal',
						'layout' => 'default',
						'hide_on_screen' => array (
						),
					),
					'menu_order' => 0,
				));
			}			
		}
		
		public function print_share_buttons( $post_id, $post_title='' )
		{
			$post_url = get_permalink( $post_id ); 
			$image_url = wp_get_attachment_url( get_post_thumbnail_id( $post_id ) );
			
			$html = array();
			   
			if( get_theme_mod('facebook_share_on', alvaro()->defaults_theme['facebook_share_on']) == 'YES' ) {
				$html[] = '<a href="http://www.facebook.com/sharer.php?u=' . urlencode( esc_url($post_url) ) . '" class="smi-facebook"><i class="fa fa-facebook" aria-hidden="true"></i></a>';
			}
			
			if( get_theme_mod('twitter_share_on', alvaro()->defaults_theme['twitter_share_on']) == 'YES' ) {
				$html[] = '<a href="https://twitter.com/share?url=' . urlencode( esc_url($post_url) ) .'&amp;text=' . urlencode( esc_attr($post_title) ) . '" class="smi-twitter"><i class="fa fa-twitter" aria-hidden="true"></i></a>';
			}
			
			if( get_theme_mod('gplus_share_on', alvaro()->defaults_theme['gplus_share_on']) == 'YES' ) {
				$html[] = '<a href="https://plus.google.com/share?url=' . urlencode( esc_url($post_url) ) . '" class="smi-googleplus"><i class="fa fa-google-plus" aria-hidden="true"></i></a>';
			}
			
			if ($image_url) {
				if( get_theme_mod('pinterest_share_on', alvaro()->defaults_theme['pinterest_share_on']) == 'YES' ) {
					$html[] = '<a href="https://pinterest.com/pin/create/button/?url=' . urlencode( esc_url($image_url) ) . '&amp;media=' . urlencode( esc_attr($post_title) ) . '&amp;description=' . urlencode( esc_attr($post_title) ) . '" class="smi-pinterest"><i class="fa fa-pinterest-p" aria-hidden="true"></i></a>';
				}
			}
			
			return implode("\n", $html);
		}

		public function alvaro_social_share( $atts )
		{ 
			$atts = extract(shortcode_atts( array(
				'post_id' => 0,
				'post_title' => null
			), $atts, 'alvaro_social_share' ));
			
			$html = array();
			
			$html[] = '<div class="alvaro-social-share">';
			$html[] = 	'<h3 class="alvaro-social-share-title">' . esc_html__('Spread The Word', 'alvaro') . '</h3>';
			$html[] = 	'<div class="alvaro-social-share-icons">';
			$html[] = 		'<div class="alvaro-smi-inner">' . ( $this->print_share_buttons(get_the_ID(), get_the_title()) ) . '</div>';
			$html[] = 	'</div>';
			$html[] = '</div>';
			
			return implode("\n", $html);
		}
		
	}
	
	new alvaroPostTypes();
}
