<?php
class Alvaro_Search_Widget extends WP_Widget {

    public function __construct() {

        parent::__construct(
            'alvaro_search_widget',
            esc_html__( 'alvaro Search Widget', 'alvaro' ),
            array(
                'classname'   => 'alvaro_search_widget',
                'description' => esc_html__ ( 'A basic search widget.', 'alvaro' )
            )
        );
    }

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget( $args, $instance ) {

        extract( $args );

        $title      = apply_filters( 'widget_title', $instance['title'] );
        $placeholder    = $instance['placeholder'];

        echo wp_kses_post( $before_widget );

        if ( $title ) {
            echo wp_kses_post( $before_title . $title . $after_title );
        }

        echo '<form action="' . ( esc_url( home_url('/') ) ) . '" class="searchform" method="get" role="search">
          <div>
            <input type="text" id="s" name="s" value="" placeholder="' . ( esc_attr( $placeholder ) ) . '">
            <button type="submit" value="'. ( esc_attr__( 'Search', 'alvaro' ) ) .'" id="searchsubmit"></button>
          </div>
        </form>';
        echo wp_kses_post( $after_widget );

    }


    /**
      * Sanitize widget form values as they are saved.
      *
      * @see WP_Widget::update()
      *
      * @param array $new_instance Values just sent to be saved.
      * @param array $old_instance Previously saved values from database.
      *
      * @return array Updated safe values to be saved.
      */
    public function update( $new_instance, $old_instance ) {

        $instance = $old_instance;

        $instance['title'] = strip_tags( $new_instance['title'] );
        $instance['placeholder'] = strip_tags( $new_instance['placeholder'] );

        return $instance;

    }

    /**
      * Back-end widget form.
      *
      * @see WP_Widget::form()
      *
      * @param array $instance Previously saved values from database.
      */
    public function form( $instance ) {
        $title          = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
        $placeholder    = isset( $instance['placeholder'] ) ? esc_attr( $instance['placeholder'] ) : '';
        ?>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('title') ); ?>"><?php esc_html_e('Title:', 'alvaro'); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('placeholder') ); ?>"><?php esc_html_e('Placeholder', 'alvaro'); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('placeholder') ); ?>" name="<?php echo esc_attr( $this->get_field_name('placeholder') ); ?>" type="text" value="<?php echo esc_attr( $placeholder ); ?>" />
        </p>

    <?php
    }

}

/* Register the widget */
add_action( 'widgets_init', function(){
     register_widget( 'alvaro_search_widget' );
});