<?php
class alvaro_recent_testimonials extends WP_Widget
{
	private $parent = null;
	private $widget_url = '';
    /**
     * Constructor
     **/
    public function __construct()
    {
    	$this->parent = alvaro();
		$this->widget_url = get_stylesheet_directory_uri() . str_replace( get_template_directory(), '', dirname(__FILE__) );

        $widget_ops = array(
            'classname' => $this->parent->alias . '_recent_testimonials',
            'description' => esc_attr__('Widget that prints recent testimonials.', 'alvaro')
        );
		
        parent::__construct( $this->parent->alias . '_recent_testimonials', esc_attr__( 'alvaro Recent Testimonials Slider', 'alvaro' ), $widget_ops );
    }

	/**
     * Upload the Javascripts for the media uploader
     */
    public function upload_scripts()
    {
    }

    /**
     * Outputs the HTML for this widget.
     *
     * @param array  An array of standard parameters for widgets in this theme
     * @param array  An array of settings for this widget instance
     * @return void Echoes it's output
     **/
    public function widget( $args, $instance )
    {
        echo wp_kses_post($args['before_widget']);

		if ( ! empty( $instance['title'] ) ) {
			echo wp_kses_post($args['before_title']) . apply_filters( 'widget_title', $instance['title'] ). wp_kses_post($args['after_title']);
		}

		$nbrows = isset($instance['post_per_widget']) ? (int)$instance['post_per_widget'] : 1;
		$custom_ids = isset($instance['custom_ids']) ? $instance['custom_ids'] : "";

		if( trim($custom_ids) != "" ){
			$custom_ids = explode( ",", $custom_ids );
			$custom_ids = array_filter( array_map('trim', $custom_ids ) );
		}
		$rPosts = new WP_Query();

		$params = array(
			'post_type' => 'testimonials',
			'posts_per_page' 		=> $nbrows,
			'orderby' 				=> 'date',
			'order'   				=> 'DESC',
			'ignore_sticky_posts' 	=> 1
		);

		if( count($custom_ids) > 0 && is_array($custom_ids) ){
			$params['post__in'] = $custom_ids;
		}

		$rPosts->query( $params );
        ?>
        <div class="<?php echo esc_attr( $this->parent->alias ); ?>-recent-testimonials">
        <?php
		while ($rPosts->have_posts()) : $rPosts->the_post();
        ?>
			<div class="alvaro-latest-testimonial">
				<div>
					<div class="alvaro-testimonial-content">
						<span class="alvaro-quote-open">“</span>
							<div><?php the_content(); ?></div>
						<span class="alvaro-quote-close">”</span>
					</div>
					<div class="alvaro-testimonial-author">
						<?php the_title();?>
					</div>
                </div>
			</div>
		<?php endwhile;
		wp_reset_postdata();

		echo wp_kses_post($args['after_widget']);
        ?>
        </div>

        <?php
    }

    /**
     * Deals with the settings when they are saved by the admin. Here is
     * where any validation should be dealt with.
     *
     * @param array  An array of new settings as submitted by the admin
     * @param array  An array of the previous settings
     * @return array The validated and (if necessary) amended settings
     **/
    public function update( $new_instance, $old_instance )
    {
		// update logic goes here
        $updated_instance = $new_instance;
        return $updated_instance;
    }

    /**
     * Displays the form for this widget on the Widgets page of the WP Admin area.
     *
     * @param array  An array of the current settings for this widget
     * @return void
     **/
    public function form( $instance )
    {
       	$title = esc_attr__('Latest Testimonials', 'alvaro');
        if(isset($instance['title']))
        {
            $title = $instance['title'];
        }

		$post_per_widget = 3;
        if(isset($instance['post_per_widget']))
        {
            $post_per_widget = $instance['post_per_widget'];
        }

		$custom_ids = "";
        if(isset($instance['custom_ids']))
        {
            $custom_ids = $instance['custom_ids'];
        }
        ?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>"><?php esc_attr_e('Title', 'alvaro'); ?>:</label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_name( 'post_per_widget' ) ); ?>"><?php esc_attr_e('Number of Testimonials', 'alvaro'); ?>:</label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'post_per_widget' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'post_per_widget' ) ); ?>" type="text" value="<?php echo esc_attr( $post_per_widget ); ?>" />
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_name( 'custom_ids' ) ); ?>"><?php esc_attr_e('Custom testimonials IDs', 'alvaro'); ?>:</label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'custom_ids' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'custom_ids' ) ); ?>" type="text" value="<?php echo esc_attr( $custom_ids ); ?>" />
        </p>
    <?php
    }
}
add_action( 'widgets_init', create_function( '', 'register_widget("alvaro_recent_testimonials");' ) );