<?php
class alvaro_twitter extends WP_Widget
{
	private $parent = null;
	private $widget_url = '';
    /**
     * Constructor
     **/
    public function __construct()
    {
    	$this->parent = alvaro();
		$this->widget_url = get_stylesheet_directory_uri() . str_replace( get_template_directory(), '', dirname(__FILE__) );

        $widget_ops = array(
            'classname' => $this->parent->alias . '_twitter',
            'description' => esc_attr__('Displays latest tweets from your twitter account.', 'alvaro')
        );

        parent::__construct( $this->parent->alias . '_twitter', ' '.esc_attr__( 'alvaro Twitter', 'alvaro' ), $widget_ops );
    }

	/**
     * Upload the Javascripts for the media uploader
     */
    public function upload_scripts()
    {
    }

    /**
     * Outputs the HTML for this widget.
     *
     * @param array  An array of standard parameters for widgets in this theme
     * @param array  An array of settings for this widget instance
     * @return void Echoes it's output
     **/
    public function widget( $args, $instance )
    {
        echo wp_kses_post($args['before_widget']);

		if ( ! empty( $instance['title'] ) ) {
			echo wp_kses_post($args['before_title']) . apply_filters( 'widget_title', $instance['title'] ). wp_kses_post($args['after_title']);
		}

		if( !isset($instance['twitter_name']) || trim($instance['twitter_name']) == '' ) {
			echo '<p>' . esc_html__('Please setup a twitter name to use this widget.', 'alvaro') . '</p>';
			echo wp_kses_post($args['after_widget']);
			return;
		}
		
		$twitter_name = $instance['twitter_name'];
		
        if ( !$number = (int) $instance['number'] )
            $number = 3;
        else if ( $number < 1 )
            $number = 1;
        else if ( $number > 12 )
            $number = 12;

        if(function_exists('getTweets')) {

            $tweets = getTweets($number, $twitter_name);  
            ?>
            <div class="twitter-widget-wrapper">
                <ul class="twitter-content slides">
                <?php
                if( !isset($tweets['error']) && is_array($tweets) && count($tweets) > 0 ){

                    foreach($tweets as $tweet){
                        ?>

                        <li>
                            <div class="gw-tweet">
                            <?php
                        if($tweet['text']){
                            $the_tweet = esc_html($tweet['text']);

                            // i. User_mentions must link to the mentioned user's profile.
                            if(is_array($tweet['entities']['user_mentions'])){
                                foreach($tweet['entities']['user_mentions'] as $key => $user_mention){
                                    $the_tweet = preg_replace(
                                        '/@'.$user_mention['screen_name'].'/i',
                                        '<a href="http://www.twitter.com/'.$user_mention['screen_name'].'" target="_blank">@'.$user_mention['screen_name'].'</a>',
                                        $the_tweet);
                                }
                            }

                            // ii. Hashtags must link to a twitter.com search with the hashtag as the query.
                            if(is_array($tweet['entities']['hashtags'])){
                                foreach($tweet['entities']['hashtags'] as $key => $hashtag){
                                    $the_tweet = preg_replace(
                                        '/#'.$hashtag['text'].'/i',
                                        '<a href="https://twitter.com/search?q=%23'.$hashtag['text'].'&src=hash" target="_blank">#'.$hashtag['text'].'</a>',
                                        $the_tweet);
                                }
                            }

                            // iii. Links in Tweet text must be displayed using the display_url field in the URL entities API response, and link to the original t.co url field.
                            if(is_array($tweet['entities']['urls'])){
                                foreach($tweet['entities']['urls'] as $key => $link){
                                    $the_tweet = preg_replace(
                                        '`'.$link['url'].'`',
                                        '<a href="'.$link['url'].'" target="_blank">'.$link['url'].'</a>',
                                        $the_tweet);
                                }
                            }

                            $html = array();

                            if ( isset($twitter_name) && $twitter_name != '' ) {
                            }

                            $html[] = '<div class="tw-content">';
                            $html[] = $the_tweet;


                            // 3. Tweet Timestamp
                            //    The Tweet timestamp must always be visible and include the time and date. e.g., “3:00 PM - 31 May 12”.
                            // 4. Tweet Permalink
                            //    The Tweet timestamp must always be linked to the Tweet permalink.

                            $html[] =   '<p class="tw-timestamp">';
                            $html[] =   '<a href="https://twitter.com/'. sanitize_text_field($twitter_name) .'/status/'.$tweet['id_str'].'" target="_blank">'.date('M d Y h:i A',strtotime($tweet['created_at'])).'</a>';
                            $html[] =   '</p>';

                            // 5. Tweet Actions

                            $html[] =   '<div class="twitter_intents">';
                            $html[] =     '<a title="reply" href="https://twitter.com/intent/tweet?in_reply_to=' . esc_attr($tweet['id_str']) . '">' . esc_attr__('reply', 'alvaro') . '</a>';
                            $html[] =     '<a title="retweet" href="https://twitter.com/intent/retweet?tweet_id=' . esc_attr($tweet['id_str']) . '">' . esc_attr__('retweet', 'alvaro') . '</a>';
                            $html[] =     '<a title="favorite" href="https://twitter.com/intent/favorite?tweet_id=' . esc_attr($tweet['id_str']) . '">' . esc_attr__('favourite', 'alvaro') . '</a>';
                            $html[] =   '</div>';

                            $html[] = '</div>';

                            echo implode($html, "\n");

                        } else { ?>
                            <a href="http://twitter.com/<?php echo sanitize_text_field($twitter_name); ?>"><?php esc_attr_e('Click here to read the twitter feed', 'alvaro'); ?></a>
                            <?php
                        } ?>

                        </div><!-- end of .gw-tweet -->
                    </li><?php
                    }// end of foreach
					echo '<li>';
                    	echo '<a class="twitter_follow" href="https://twitter.com/'. sanitize_text_field($twitter_name) .'" target="_blank">' . ( esc_attr__('Follow Us', 'alvaro') ) . '</a>';
					echo '</li>';
                }// end of is_array
                ?>
                </ul>
            </div>
            <?php } else { ?>
                <ul class="twitter-content">
                <li><?php esc_attr_e('Please install the oAuth Twitter Feed for Developers plugin to have a working twitter widget.', 'alvaro'); ?></li>
                </ul>
            <?php }

		echo wp_kses_post($args['after_widget']);
        ?>
        <?php
    }

    /**
     * Deals with the settings when they are saved by the admin. Here is
     * where any validation should be dealt with.
     *
     * @param array  An array of new settings as submitted by the admin
     * @param array  An array of the previous settings
     * @return array The validated and (if necessary) amended settings
     **/
    public function update( $new_instance, $old_instance )
    {
		// update logic goes here
        $updated_instance = $new_instance;
        return $updated_instance;
    }

    /**
     * Displays the form for this widget on the Widgets page of the WP Admin area.
     *
     * @param array  An array of the current settings for this widget
     * @return void
     **/
    public function form( $instance )
    {
       	$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
        $twitter_name = isset($instance['twitter_name']) ? esc_attr($instance['twitter_name']) : '';
        if ( !isset($instance['number']) || !$number = (int) $instance['number'] )
            $number = 3;
        ?>

        <p><label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_attr_e('Title', 'alvaro'); ?>:</label>
        <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

        <p><label for="<?php echo esc_attr($this->get_field_id('twitter_name')); ?>"><?php esc_attr_e('Twitter username', 'alvaro'); ?>:</label>
        <input class="widefat" id="<?php echo esc_attr($this->get_field_id('twitter_name')); ?>" name="<?php echo esc_attr($this->get_field_name('twitter_name')); ?>" type="text" value="<?php echo esc_attr($twitter_name); ?>" /></p>

        <p><label for="<?php echo esc_attr($this->get_field_id('number')); ?>"><?php esc_attr_e('Number of tweets', 'alvaro'); ?>:</label>
        <input class="widefat" id="<?php echo esc_attr($this->get_field_id('number')); ?>" name="<?php echo esc_attr($this->get_field_name('number')); ?>" type="text" value="<?php echo esc_attr($number); ?>" /></p>

        <?php
    }
}
add_action( 'widgets_init', create_function( '', 'register_widget("alvaro_twitter");' ) );