<?php
! defined( 'ABSPATH' ) and exit;
if(class_exists('WE_Customize') != true) {

	if(class_exists('Custom_Html_Control') != true && class_exists('WP_Customize_Control') == true )
	{
		class Custom_Html_Control extends WP_Customize_Control
		{
			public $type = 'customhtml';
			public $extra = ''; // we add this for the extra description
			public function render_content() {
			?>
				<label>
					<?php if ( ! empty( $this->label ) ) : ?>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<?php endif;
					if ( ! empty( $this->description ) ) : ?>
					<span class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
					<?php endif; ?>
					<textarea style="width: 100%; min-height: 100px;" <?php $this->link(); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
				</label>
			<?php
			}
		}
	}

	class alvaro_Customize
	{
		public $the_theme = null;

		/* 1. The class constructor
		=========================== */
		public function __construct( $the_theme=array() )
		{
			$this->the_theme = $the_theme;

			add_action( 'customize_register', array( $this, 'theme_customizer' ) );
			add_action( 'customize_controls_print_scripts', array( $this, 'customizer_js' ) );
		}

		public function theme_customizer( $wp_customize )
		{
			// Configure site pages
			$pages = get_pages();
			if( count($pages) > 0 ) {
				$alvaro_get_pages = array();
				foreach( $pages as $page ) {
					$alvaro_get_pages[$page->ID] = $page->post_title;
				}

				$wp_customize->add_section( 'pages_section' , array(
				    'title'       => esc_html__( 'Configure Pages', 'alvaro' ),
				    'priority'    => 30,
				    'description' => esc_html__( 'Select your pages.', 'alvaro' ),
				) );

				$wp_customize->add_setting( 'camping_page', array(
			        'default'           => '19',
			        'sanitize_callback' => 'wp_kses_post',
			    ) );
				$wp_customize->add_control( 'camping_page', array(
			        'label'	   => esc_html__( 'Camping Page', 'alvaro' ),
			        'section'  => 'pages_section',
			        'type'	   => 'select',
			        'choices'  => $alvaro_get_pages
			    ) );

			    $wp_customize->add_setting( 'species_page', array(
			        'default'           => '21',
			        'sanitize_callback' => 'wp_kses_post',
			    ) );
			    $wp_customize->add_control( 'species_page', array(
			        'label'	   => esc_html__( 'Species Page', 'alvaro' ),
			        'section'  => 'pages_section',
			        'type'	   => 'select',
			        'choices'  => $alvaro_get_pages
			    ) );
			}

			// Blog OPTIONS
			$wp_customize->add_section( 'blog_section' , array(
				'title'       => esc_html__( 'Blog', 'alvaro' ),
				'priority'    => 30,
				'description' => 'Modify blog options',
			) );
			
			$wp_customize->add_setting( 'blog_layout', array(
				'default'           => 'normal',
				'sanitize_callback' => 'sanitize_text_field',
			) );
			
			$wp_customize->add_control( 'blog_layout', array(
				'label'	   => esc_html__( 'Blog layout', 'alvaro' ),
				'section'  => 'blog_section',
				'type'	   => 'select',
				'choices'  => array( 'normal' => esc_html__('Normal', 'alvaro'), 'alternate' => esc_html__('Alternate', 'alvaro') )
			) );

			// LOGO OPTONS
			$wp_customize->add_section( 'logo_section' , array(
				'title'       => esc_html__( 'Logo', 'alvaro' ),
				'priority'    => 30,
				'description' => esc_html__('Upload a logo to replace the default logo from header.', 'alvaro'),
			) );

			$wp_customize->add_setting( 'logo', array(
				'sanitize_callback' => 'esc_url_raw',
			) );

			$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'logo', array(
				'label'    => esc_html__( 'Logo', 'alvaro' ),
				'section'  => 'logo_section',
				'settings' => 'logo',
			) ) );
			
			// Site colors
			if( count($this->the_theme->colors) > 0 ){
				foreach ($this->the_theme->colors as $key => $color) {

					$wp_customize->add_setting( $key, array(
						'default'           => $color['color'],
						'transport'         => 'postMessage',
						'sanitize_callback' => 'sanitize_hex_color',
					) );

					$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $key, array(
						'label'	   => $color['name'],
						'section'  => 'colors',
						'settings' => $key
					) ) );
				}
			}

			// Site fonts
			$google_fonts = $this->the_theme->get_google_fonts();
			if( count($google_fonts) > 0 ) {
				$wp_customize->add_section( 'fonts_section' , array(
					'title'       => esc_html__( 'Theme Fonts', 'alvaro' ),
					'priority'    => 30,
					'description' => esc_html__('Select your desired theme fonts from Google Fonts collection.', 'alvaro'),
				) );

				$wp_customize->add_setting( 'font_main', array(
					'default'           => 'Barlow',
					'sanitize_callback' => 'sanitize_text_field',
				) );
				$wp_customize->add_control( 'font_main', array(
					'label'	   => esc_html__( 'Main font', 'alvaro' ),
					'section'  => 'fonts_section',
					'type'	   => 'select',
					'choices'  => $google_fonts
				) );
				
				$wp_customize->add_setting( 'font_secondary', array(
					'default'           => 'Nunito',
					'sanitize_callback' => 'sanitize_text_field',
				) );
				$wp_customize->add_control( 'font_secondary', array(
					'label'	   => esc_html__( 'Secondary font', 'alvaro' ),
					'section'  => 'fonts_section',
					'type'	   => 'select',
					'choices'  => $google_fonts
				) );
			}
			
			// Configure sharing
			$wp_customize->add_section( 'sharing_section' , array(
				'title'       => esc_html__( 'Configure Sharing', 'alvaro' ),
				'priority'    => 30,
				'description' => esc_html__('AddThis profile ID.', 'alvaro'),
			) );
			
			// Facebook share
			$wp_customize->add_setting( 'facebook_share_on', array(
				'default'           => 'YES',
				'sanitize_callback' => 'sanitize_text_field',
			) );
			
			$wp_customize->add_control( 'facebook_share_on', array(
				'label'	   => esc_html__( 'Enable Facebook Sharing', 'alvaro' ),
				'section'  => 'sharing_section',
				'type'	   => 'select',
				'choices'  => array( 'YES' => esc_html__('YES', 'alvaro'), 'NO' => esc_html__('NO', 'alvaro') )
			) );
			
			// Facebook share
			$wp_customize->add_setting( 'pinterest_share_on', array(
				'default'           => 'YES',
				'sanitize_callback' => 'sanitize_text_field',
			) );
			
			$wp_customize->add_control( 'pinterest_share_on', array(
				'label'	   => esc_html__( 'Enable Pinterest Sharing', 'alvaro' ),
				'section'  => 'sharing_section',
				'type'	   => 'select',
				'choices'  => array( 'YES' => esc_html__('YES', 'alvaro'), 'NO' => esc_html__('NO', 'alvaro') )
			) );
			
			// Twitter share
			$wp_customize->add_setting( 'twitter_share_on', array(
				'default'           => 'YES',
				'sanitize_callback' => 'sanitize_text_field',
			) );
			
			$wp_customize->add_control( 'twitter_share_on', array(
				'label'	   => esc_html__( 'Enable Twitter Sharing', 'alvaro' ),
				'section'  => 'sharing_section',
				'type'	   => 'select',
				'choices'  => array( 'YES' => esc_html__('YES', 'alvaro'), 'NO' => esc_html__('NO', 'alvaro') )
			) );
			
			// Google+ share
			$wp_customize->add_setting( 'gplus_share_on', array(
				'default'           => 'YES',
				'sanitize_callback' => 'sanitize_text_field',
			) );
			
			$wp_customize->add_control( 'gplus_share_on', array(
				'label'	   => esc_html__( 'Enable Google+ Sharing', 'alvaro' ),
				'section'  => 'sharing_section',
				'type'	   => 'select',
				'choices'  => array( 'YES' => esc_html__('YES', 'alvaro'), 'NO' => esc_html__('NO', 'alvaro') )
			) );

			// HEADER OPTIONS
			$wp_customize->add_section( 'header_section' , array(
				'title'       => esc_html__( 'Header Options', 'alvaro' ),
				'priority'    => 30,
				'description' => '',
			) );

			$wp_customize->add_setting( 'header_bg', array(
				'sanitize_callback' => 'esc_url_raw',
			) );

			$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'header_bg', array(
				'label'    => esc_html__( 'Header Background', 'alvaro' ),
				'section'  => 'header_section',
				'settings' => 'header_bg',
			) ) );
			
			// FOOTER OPTIONS
			$wp_customize->add_section( 'footer_section' , array(
				'title'       => esc_html__( 'Footer Options', 'alvaro' ),
				'priority'    => 30,
				'description' => '',
			) );

			$wp_customize->add_setting( 'footer_copyright_text', array(
				'default'           => 'Copyright © 2017 alvaro. All rights reserved. Created by AA-Team.',
				'sanitize_callback' => 'wp_kses_post',
			) );
			
			$wp_customize->add_control( 'footer_copyright_text', array(
				'label'	   => esc_html__( 'Footer copyright text', 'alvaro' ),
				'section'  => 'footer_section',
				'type'	   => 'textarea',
			) );
		}

		public function customizer_js()
		{
			wp_enqueue_script( $this->the_theme->alias . '-colors', get_stylesheet_directory_uri() . '/customizer/colors.js', array( 'jquery' ), '1.0', true);
		}

	}
}