<?php
/**
 * @package WordPress
 * @subpackage:
 *	Name: 	alvaro
 *	Alias: 	alvaro
 *	Author: AA-Team
 *	Name: 	http://themeforest.net/user/AA-Team/portfolio
 *
**/
! defined( 'ABSPATH' ) and exit;

if(class_exists('alvaro') != true) {
	class alvaro
	{
		protected static $instance = null;

		// shortcuts
		public $locName = 'alvaro';
		public $alias = 'alvaro';
		public $theme_name = 'alvaro';
		public $wp_filesystem = null;

		public $cfg = array();

		public $page_layout = array();
		public $colors = array();
		public $need_refresh_css = false;

		public $defaults_theme = array();

		/**
		 * Call this method to get singleton
		 *
		 * @return current class
		 */
		public static function getInstance()
		{
			if (!isset(static::$instance)) {
				static::$instance = new alvaro();
			}
			return static::$instance;
		}

		/* 1. The class constructor
		=========================== */
		public function __construct()
		{
			load_theme_textdomain('alvaro', get_template_directory() . '/languages');
			
			// load WP_Filesystem 
			include_once ABSPATH . 'wp-admin/includes/file.php';
			WP_Filesystem();
			global $wp_filesystem;
			$this->wp_filesystem = $wp_filesystem;

			$this->set_default_theme_mods();
			
			$this->add_theme_colors();

			$this->cfg['css_cache_time'] = 1; // seconds

			$this->cfg['fonts'] = array(
				'font_main' => 'Barlow:400,400i,500,500i,600,700,700i',
				'font_secondary' => 'Nunito:400,400i,600,700,800'
			);
			
			add_action('wp_ajax_alvaro_frontend_style', array( $this, 'frontend_style') );
			add_action('wp_ajax_nopriv_alvaro_frontend_style', array( $this, 'frontend_style') );

			add_action('after_setup_theme', array( $this, 'alvaro_setup_theme' ));

			/* Declare WooCommerce Support */
			add_action( 'after_setup_theme', 'woocommerce_support' );
			function woocommerce_support() {
				add_theme_support( 'woocommerce' );
			}

			// load only for frotend
			if ( !is_admin() ) {
				add_action( 'wp_enqueue_scripts', array( $this, 'add_styles' ), 10);
				add_action( 'wp_enqueue_scripts', array( $this, 'add_scripts' ));
			}

			register_nav_menus( array(
				$this->alias . '-main-left-menu' => esc_html__( 'Main Left Menu', 'alvaro' ),
				$this->alias . '-main-right-menu' => esc_html__( 'Main Right Menu', 'alvaro' ),
				$this->alias . '-footer-menu' => esc_html__( 'Footer Menu', 'alvaro' )
			) );

			/**
			 * Include the TGM_Plugin_Activation class.
			 */
			require_once get_template_directory() . '/inc/class-tgm-plugin-activation.php';

			// load Customizer
			require_once( get_template_directory() . '/customizer/customize.class.php' );
			new alvaro_Customize( $this );
			
			// if woo sidebars installed add meta box
			if( class_exists( 'Woo_Sidebars' ) === true ){
				add_action( 'admin_enqueue_scripts', array( $this, 'load_admin_style' ) );
			}

			add_action( 'tgmpa_register', array( $this, 'register_required_plugins' ) );

			add_action('comment_post', array($this, 'save_rating')); // Save Rating Field on Comment Post

			add_action( 'wp', array( $this, 'update_page_layout' ), 10 );

			add_filter( 'avatar_defaults', array( $this, 'default_avatar' ) );

			$this->page_layout['comments-as-reviews'] = false;

			add_filter( 'widget_tag_cloud_args', array( $this, 'tag_cloud_filter' ) );

			// get share count
			add_action('wp_ajax_alvaro_get_share_count', array( $this, 'get_share_count') );
			add_action('wp_ajax_nopriv_alvaro_get_share_count', array( $this, 'get_share_count') );

			if ( ! isset( $content_width ) ) $content_width = 1170;

			add_theme_support( 'automatic-feed-links' );
			add_filter('loop_shop_columns', array( $this, 'loop_columns' ), 999);
			add_filter( 'woocommerce_get_availability', array( $this, 'custom_override_get_availability' ), 1, 2);
			
			add_filter( 'yith_wcwl_before_wishlist', array( $this, 'yith_wcwl_before_wishlist' ) );
			add_filter( 'yith_wcwl_after_wishlist', array( $this, 'yith_wcwl_after_wishlist' ) );
			
			add_filter( 'woocommerce_enqueue_styles', array( $this, 'remove_woocommerce_styles' ) );
			
		}

		public function set_default_theme_mods()
		{
			$this->defaults_theme["camping_page"] = "19";
			$this->defaults_theme["species_page"] = "21";
			$this->defaults_theme["blog_layout"] = "normal";
			$this->defaults_theme["primary_color"] = "709448";
			$this->defaults_theme["secondary_color"] = "1761c6";
			$this->defaults_theme["menubg"] = "131c50";
			$this->defaults_theme["font_main"] = "Barlow";
			$this->defaults_theme["font_secondary"] = "Nunito";
			$this->defaults_theme["facebook_share_on"] = "YES";
			$this->defaults_theme["pinterest_share_on"] = "YES";
			$this->defaults_theme["twitter_share_on"] = "YES";
			$this->defaults_theme["gplus_share_on"] = "YES";
			$this->defaults_theme["footer_copyright_text"] = "Copyright © 2019 Alvaro. All rights reserved. Created by AA-Team.";
			
		}

		public function remove_woocommerce_styles( $enqueue_styles )
		{
			unset( $enqueue_styles['woocommerce-layout'] );
			return $enqueue_styles;
		}
		
		public function yith_wcwl_before_wishlist ()
		{
			echo '<div class="yith_wishlist_container">';
		}
		
		public function yith_wcwl_after_wishlist ()
		{
			echo '</div>';
		}

		public function register_required_plugins()
		{
			$plugins = array(

				array(
					'name'     				=> esc_html__('WooSidebars', 'alvaro'),
					'slug'     				=> 'woosidebars',
					'source'   				=> 'https://github.com/woothemes/woosidebars/archive/master.zip',
					'required' 				=> false,
					'force_activation' 		=> false,
					'force_deactivation' 	=> false,
					'external_url' 			=> '',
				),
				
				array(
					'name'     				=> esc_html__('AA Backup Manager', 'alvaro'),
					'slug'     				=> 'aa-backup-manager',
					'source'   				=> get_template_directory() . '/plugins/aa-backup-manager.zip',
					'required' 				=> false,
					'version' 				=> '1.1',
					'force_activation' 		=> false,
					'force_deactivation' 	=> false,
					'external_url' 			=> '',
				),
				
				array(
					'name'     				=> esc_html__('AA Customizer Site Beautify', 'alvaro'),
					'slug'     				=> 'customizer-site-beautify',
					'source'   				=> get_template_directory() . '/plugins/customizer-site-beautify.zip',
					'required' 				=> false,
					'version' 				=> '1.1',
					'force_activation' 		=> false,
					'force_deactivation' 	=> false,
					'external_url' 			=> '',
				),
				
				array(
					'name'     				=> esc_html__('alvaro - Custom Post Types', 'alvaro'),
					'slug'     				=> 'alvaro-postTypes',
					'source'   				=> get_template_directory() . '/plugins/alvaro-postTypes.zip',
					'required' 				=> false,
					'version' 				=> '1.0', 
					'force_activation' 		=> false,
					'force_deactivation' 	=> false,
					'external_url' 			=> '',
				),
				
				array(
					'name'     				=> esc_html__('Revolution Slider', 'alvaro'),
					'slug'     				=> 'revslider',
					'source'   				=> get_template_directory() . '/plugins/slider-revolution-responsive-wordpress-plugin-wordpress-plugin.zip',
					'required' 				=> false,
					'version' 				=> '5.4.8', 
					'force_activation' 		=> false,
					'force_deactivation' 	=> false,
					'external_url' 			=> '',
				),
				
				array(
					'name'     				=> esc_html__('Visual Composer', 'alvaro'),
					'slug'     				=> 'js_composer',
					'source'   				=> get_template_directory() . '/plugins/visual-composer-page-builder-for-wordpress-wordpress-plugin.zip',
					'required' 				=> false,
					'version' 				=> '5.5.5', 
					'force_activation' 		=> false,
					'force_deactivation' 	=> false,
					'external_url' 			=> '',
				),
				
				array(
					'name'     				=> esc_html__('alvaro - Visual Composer Extended', 'alvaro'),
					'slug'     				=> 'js-composer-extend-alvaro',
					'source'   				=> get_template_directory() . '/plugins/js-composer-extend-alvaro.zip',
					'required' 				=> false,
					'version' 				=> '1.0', 
					'force_activation' 		=> false,
					'force_deactivation' 	=> false,
					'external_url' 			=> '',
				),

				array(
					'name' 		=> esc_html__('Advanced Custom Fields', 'alvaro'),
					'slug' 		=> 'advanced-custom-fields',
					'required' 	=> false,
				),


				array(
					'name' 		=> esc_html__('Contact Form 7', 'alvaro'),
					'slug' 		=> 'contact-form-7',
					'required' 	=> false,
				),
				

				array(
					'name' 		=> esc_html__('WooCommerce', 'alvaro'),
					'slug' 		=> 'woocommerce',
					'required' 	=> false,
				),


				array(
					'name' 		=> esc_html__('YITH WooCommerce Compare', 'alvaro'),
					'slug' 		=> 'yith-woocommerce-compare',
					'required' 	=> false,
				),

				
				array(
					'name' 		=> esc_html__('YITH WooCommerce Wishlist', 'alvaro'),
					'slug' 		=> 'yith-woocommerce-wishlist',
					'required' 	=> false,
				),


				array(
					'name' 		=> esc_html__('oAuth Twitter Feed for Developers', 'alvaro'),
					'slug' 		=> 'oauth-twitter-feed-for-developers',
					'required' 	=> false,
				)
			);

			/*
			 * Array of configuration settings. Amend each line as needed.
			 *
			 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
			 * strings available, please help us make TGMPA even better by giving us access to these translations or by
			 * sending in a pull-request with .po file(s) with the translations.
			 *
			 * Only uncomment the strings in the config array if you want to customize the strings.
			 */
			$config = array(
				'id'           => 'alvaro',				// Unique ID for hashing notices for multiple instances of TGMPA.
				'default_path' => '',						// Default absolute path to bundled plugins.
				'menu'         => 'tgmpa-install-plugins',	// Menu slug.
				'has_notices'  => true,						// Show admin notices or not.
				'dismissable'  => true,						// If false, a user cannot dismiss the nag message.
				'dismiss_msg'  => '',						// If 'dismissable' is false, this message will be output at top of nag.
				'is_automatic' => false,					// Automatically activate plugins after installation or not.
				'message'      => '',						// Message to output right before the plugins table.
			);

			tgmpa( $plugins, $config );
		}


		public function get_google_fonts( $what='all' ) 
		{   
			$fonts = json_decode($this->wp_filesystem->get_contents( get_template_directory() . '/fonts/googlefonts/google-webfonts.json' ), true);
			
			$ret_fonts = array();
			if(count($fonts['items']) > 0 ){ 
				foreach ( $fonts['items'] as $font ) {
					$ret_fonts[$font['family']] = $font['family'];
				}
			}
			
			if( $what == 'all' ){
				return $ret_fonts;
			}
		}

		public function add_theme_colors()
		{
			$this->colors['primary_color'] = array(
				'color' => '#709448',
				'name'	=> esc_html__('Primary Color', 'alvaro')
			);

			$this->colors['secondary_color'] = array(
				'color' => '#1761c6',
				'name'	=> esc_html__('Secondary Color', 'alvaro')
			);

			$this->colors['menubg'] = array(
				'color' => '#0c203c',
				'name'	=> esc_html__('Menu Background Color', 'alvaro')
			);
			
			$this->colors['light_blue'] = array(
				'color' => '#48daf0',
				'name'	=> esc_html__('Tertiary Color', 'alvaro')
			);
		}

		public function alvaro_setup_theme()
		{
			add_theme_support( 'title-tag' );
			add_theme_support( 'post-thumbnails' );
			
			add_theme_support( 'wc-product-gallery-zoom' );
			add_theme_support( 'wc-product-gallery-lightbox' );
			add_theme_support( 'wc-product-gallery-slider' );
			
			add_image_size( 'alvaro-camping-locations', 510, 390, true );
			
			add_action( 'widgets_init', array( $this, 'widgets_init' ) );

			add_filter('excerpt_length', array( $this, 'excerpt_length' ), 999 );
		}

		public function thumbnail_size()
		{
			if( isset($_REQUEST['page'])  ){
				if( $_REQUEST['page'] == 'regenerate-thumbnails' ){
					$_REQUEST['post_id'] = $_REQUEST['ids'];
				}
			}

			if( isset($_REQUEST['action']) ){
				if( $_REQUEST['action'] == 'editpost' ){
					$_REQUEST['post_id'] = $_REQUEST['post_ID'];
				}

				if( $_REQUEST['action'] == 'edit' ){
					$_REQUEST['post_id'] = $_REQUEST['post'];
				}
			}

			if( ! empty( $_REQUEST[ 'post_id' ] ) && ctype_digit( $_REQUEST[ 'post_id' ] ) ) {

				$post_type = get_post_type( $_REQUEST['post_id'] );

				if( $post_type == 'attachment' ){
					$parent_id = get_post_field( 'post_parent', $_REQUEST['post_id'] );
					$_post = get_post( $parent_id );
					$post_type = $_post->post_type;
				}
				if( $post_type == 'movies' ) {
					set_post_thumbnail_size( 50, 70, false );
				}
				elseif( $post_type == 'post' ) { 
					set_post_thumbnail_size( 250, 250, true );
				}
			}
		}

		public function fonts_url() {
			$font_urls = array();
			
			/*
			Translators: If there are characters in your language that are not supported
			by chosen font(s), translate this to 'off'. Do not translate into your own language.
			 */
			if ( 'off' !== esc_html_x( 'on', 'Google font: on or off', 'alvaro' ) ) {
				foreach ($this->cfg['fonts'] as $font_key => $font) {

					if($font_key != 'font_headings') {
						
						$_fontname = explode( ":", $font );
						$fontname = $_fontname[0];

						$new_font = get_theme_mod( $font_key, $this->defaults_theme[$font_key] );

						if( trim($new_font) != "" ){
							$fontname = str_replace( $fontname, $new_font, $fontname );
							$font = $fontname .':'. $_fontname[1];
						}
						
						$font_urls[] = $font;

					}
				}
			}
			return add_query_arg( 'family', urlencode( implode('|', array_unique($font_urls)) ), "//fonts.googleapis.com/css");
		}
		
		public function sanitize_hex_color( $color ) 
		{
			if ( '' === $color )
				return '';
		
			// 3 or 6 hex digits, or the empty string.
			if ( preg_match('|^#([A-Fa-f0-9]{3}){1,2}$|', $color ) )
				return $color;
		
			return null;
		}
		
		public function frontend_style() 
		{
			$start = microtime(true);
	
			$main_file = $this->wp_filesystem->get_contents( get_template_directory() . "/css/styles.css" );
			 
			// replace colors if custom user selection
			if( count($this->colors) > 0 ){
				foreach ($this->colors as $color_key => $color) {
					$new_color = $this->sanitize_hex_color( get_theme_mod( $color_key, $this->defaults_theme[$color_key] ) );

					if( trim($new_color) != "" ){
						$main_file = str_replace( $color['color'], $new_color, $main_file );
					}
				}
			}
			 
			// replace fonts if custom user selection  
			if( count($this->cfg['fonts']) > 0 ){
				foreach ($this->cfg['fonts'] as $font_key => $font) {
					$new_font = get_theme_mod( $font_key, $this->defaults_theme[$font_key] );
					
					if( trim($new_font) != "" ){
						$font = explode(':', $font);
						$main_file = str_replace( $font[0], $new_font, $main_file );
					}
				}
			}
			
			$main_file = str_replace( "../images/", get_template_directory_uri() . "/images/", $main_file );
			$main_file = str_replace( "../fonts/", get_template_directory_uri() . "/fonts/", $main_file );
			
			$time_elapsed_secs = microtime(true) - $start;
			$main_file .= "\n\n/*** Compile time: $time_elapsed_secs */";
			
			if( $this->need_refresh_css != true ){
				// Enable caching
				header('Cache-Control: public');
	
				// Expire in one day
				header('Expires: ' . gmdate('D, d M Y H:i:s', time() + 86400) . ' GMT');
	
				// Set the correct MIME type, because Apache won't set it for us
				header("Content-type: text/css");
			}

			// Write everything out
			echo wp_strip_all_tags($main_file);
			
			$this->wp_filesystem->put_contents( get_template_directory() . '/css/styles.css', $main_file );
			
			die;
		}

		public function add_styles()
		{ 
			$protocol = is_ssl() ? 'https' : 'http';

			// load frontend google fonts
			if( count($this->cfg['fonts']) > 0 ){
				wp_enqueue_style( $this->alias . '-fonts', $this->fonts_url(), array(), null );
			}

			wp_enqueue_style( $this->alias . '-bootstrap-min',		get_stylesheet_directory_uri() . '/css/bootstrap.min.css', array() );
			wp_enqueue_style( 'font-awesome',						get_stylesheet_directory_uri() . '/css/font-awesome.min.css', array() );
			wp_enqueue_style( $this->alias . '-moon-icons',			get_stylesheet_directory_uri() . '/css/moon-icons.css', array() );
			wp_enqueue_style( 'magnific-popup',						get_stylesheet_directory_uri() . '/css/magnific-popup.css', array() );
			
			$main_style = admin_url('admin-ajax.php?action=alvaro_frontend_style');
			$main_style_cached = get_stylesheet_directory() . '/css/compiled-style.css';
			
			wp_enqueue_style( 'alvaro-style', get_stylesheet_directory_uri() . '/style.css', array() );
			wp_enqueue_style( 'alvaro-master-style', $main_style, array( $this->alias . '-bootstrap-min', 'font-awesome' ) );

			if( is_singular() && comments_open() && get_option('thread_comments') ) wp_enqueue_script( 'comment-reply' );
		}

		public function add_scripts()
		{
			wp_enqueue_script( 'google-api', 						'//apis.google.com/js/platform.js', array(), '', true);
			wp_enqueue_script( 'bootstrap',							get_template_directory_uri() . '/js/bootstrap.min.js', array('jquery'), '1.0', true);
			wp_enqueue_script( 'easing',							get_template_directory_uri() . '/js/easing.js', array('jquery'), '1.0', true);			
			wp_enqueue_script( 'magnific-popup',					get_template_directory_uri() . '/js/jquery.magnific-popup.min.js', array('jquery'), '1.0', true);
			wp_enqueue_script( 'superfish',							get_template_directory_uri() . '/js/superfish.min.js', array('jquery'), '1.0', true);		
			wp_enqueue_script( $this->alias . '-main',				get_template_directory_uri() . '/js/main.js', array('jquery'), '1.0', true);
			
			if( get_theme_mod( 'addthis_profile_id' ) != '' ) {
				wp_enqueue_script( 'addthis',						'//s7.addthis.com/js/300/addthis_widget.js#pubid=' . (get_theme_mod( 'addthis_profile_id' )), array(), '1.0', true);
			}
			
			wp_localize_script($this->alias . '-main', 'js_vars', array(
				'ajaxurl' => admin_url('admin-ajax.php')
			));

			wp_enqueue_script( 'html5shiv', get_template_directory_uri() . '/js/html5.js' );
			wp_script_add_data( 'html5shiv', 'conditional', 'lt IE 9' );
		}

		public function load_admin_style()
		{
			wp_enqueue_style( $this->alias . '-moon-icons',	get_stylesheet_directory_uri() . '/css/moon-icons.css', array() );
			wp_enqueue_style( $this->alias . '-admin-css', get_stylesheet_directory_uri() . '/css/admin-style.css', false, '1.0.0' );
			wp_enqueue_script( $this->alias . '-admin-script', get_template_directory_uri() . '/js/admin.js', array('jquery'), '1.0', true);
		}

		public function print_sidebar( $location="", $in_position='', $size='' )
		{
			global $sidebars_widgets;
			
			if( is_active_sidebar( $location ) ) {
				if( class_exists( 'Woo_Sidebars' ) === true ){ 
					$sidebar_position = $this->sidebar_position( $location );
					 
					if( $sidebar_position['position'] == $in_position && isset($sidebar_position['sidebar']) ){
						$class = '';
					
						if( isset($sidebar_position['position']) && $sidebar_position['position'] != "none" ){
							$class = 'col-lg-3 col-md-3';
							if( trim($size) != "" ) $class = $size;
						?>
							<div class="<?php echo esc_attr($class); ?> alvaro-sidebar sidebar">
								<?php dynamic_sidebar( $location ); ?>
							</div>
						<?php
						}
					}
				}else{
					if( $in_position == 'right' ) {
						$class = 'col-lg-3 col-md-3';
						if( trim($size) != "" ) $class = $size;
				?>
						<div class="<?php echo esc_attr($class); ?> alvaro-sidebar sidebar">
							<?php dynamic_sidebar( $location ); ?>
						</div>
				<?php
					}
				}
			}
		}

		public function content_class( $location="", $return='echo', $size='' )
		{
			$class = 'col-md-12 alvaro-no-sidebar';
			
			if( is_active_sidebar($location) ) {
				$sidebar_position = $this->sidebar_position( $location );
				
				if( ((isset($sidebar_position['sidebar']) && is_active_sidebar('main-sidebar')) && 
					(isset($sidebar_position['position']) && $sidebar_position['position'] != "none")) || class_exists( 'Woo_Sidebars' ) === false )
				{
					$class = 'col-lg-9 col-md-9 inner-content';
					if( trim($size) != "" ) $class = $size;
				}
			}

			if( $return == 'echo' ){
				echo esc_html( $class );
			}

			else{
				return $class;
			}
		}

		public function sidebar_position( $location='' )
		{
			if( class_exists( 'Woo_Sidebars' ) === true ) {
				global $woosidebars, $sidebars_widgets;
				$woosidebars->replace_sidebars($sidebars_widgets);
				global $woo_custom_sidebar_data;
			}
			   
			if( isset($woo_custom_sidebar_data) && count($woo_custom_sidebar_data) > 0 ){
				foreach ($woo_custom_sidebar_data as $key => $value) {
					if( $location == $key ){ 
						return array(
							'position' 	=> get_post_meta( $value->ID, "_alvaro_sidebar_position", true ),
							'sidebar'	=> $value->post_name
						);
					}
				}
			}
			
			return true;
		}

		private function split_footer_columns( $nb=0 )
		{
			$def = 'col-md-3';
			if( $nb > 0 ){
				switch ($nb) {
					case 12:
						$def = 'col-xs-12 col-sm-6 col-md-2 col-lg-1';
						break;
					case 6:
						$def = 'col-xs-12 col-sm-6 col-md-2 col-lg-2';
						break;
					case 4:
						$def = 'col-xs-12 col-sm-6 col-md-3 col-lg-3';
						break;
					case 3:
						$def = 'col-xs-12 col-sm-4 col-md-4 col-lg-4';
						break;
					case 2:
						$def = 'col-xs-12 col-sm-6 col-md-6 col-lg-6';
						break;
					default:
						$def = 'col-xs-12 col-sm-12 col-sm-12 col-lg-12';
						break;
				}
			}

			return $def;
		}
		
		public function widgets_init()
		{
			register_sidebar( array(
					'name' => esc_html__( 'Main Sidebar', 'alvaro' ),
					'id' => 'main-sidebar',
					'description' => esc_html__( 'Widgets in this area will be shown on all posts and pages.', 'alvaro' ),
					'before_widget' => '<div id="%1$s" class="widget %2$s">', 
					'after_widget'  => '</div>',
					'before_title'  => '<h3 class="widgettitle">',
					'after_title'   => '</h3>',
				)
			);

			register_sidebar( array(
					'name' => esc_html__( 'Footer Sidebar 1', 'alvaro' ),
					'id' => 'fsidebar-1',
					'description' => esc_html__( 'First footer sidebar(from left to right) that appears in the footer section of the site.', 'alvaro' ),
					'before_widget'  => '<div id="%1$s" class="widget %2$s">', 
					'after_widget'  => '</div>',
					'before_title'  => '<h3 class="widgettitle">',
					'after_title'   => '</h3>',
				)
			);	

			register_sidebar( array(
					'name' => esc_html__( 'Footer Sidebar 2', 'alvaro' ),
					'id' => 'fsidebar-2',
					'description' => esc_html__( 'Second footer sidebar(from left to right) that appears in the footer section of the site.', 'alvaro' ),
					'before_widget'  => '<div id="%1$s" class="widget %2$s">', 
					'after_widget'  => '</div>',
					'before_title'  => '<h3 class="widgettitle">',
					'after_title'   => '</h3>',
				)
			);	

			register_sidebar( array(
					'name' => esc_html__( 'Footer Sidebar 3', 'alvaro' ),
					'id' => 'fsidebar-3',
					'description' => esc_html__( 'Third footer sidebar(from left to right) that appears in the footer section of the site.', 'alvaro' ),
					'before_widget'  => '<div id="%1$s" class="widget %2$s">', 
					'after_widget'  => '</div>',
					'before_title'  => '<h3 class="widgettitle">',
					'after_title'   => '</h3>',
				)
			);

			register_sidebar( array(
					'name' => esc_html__( 'Footer Sidebar 4', 'alvaro' ),
					'id' => 'fsidebar-4',
					'description' => esc_html__( 'Fourth footer sidebar(from left to right) that appears in the footer section of the site.', 'alvaro' ),
					'before_widget'  => '<div id="%1$s" class="widget %2$s">', 
					'after_widget'  => '</div>',
					'before_title'  => '<h3 class="widgettitle">',
					'after_title'   => '</h3>',
				)
			);							
				
		}

		public function remove_empty_p($content)
		{
			return preg_replace('#<p>\s*+(<br\s*/*>)?\s*</p>#i', '', $content);
		}

		public function comment_template($comment, $args, $depth)
		{
			$GLOBALS['comment'] = $comment;
			extract($args, EXTR_SKIP);

			$comment_rating = (int)get_comment_meta($comment->comment_ID, '_rating', true );
		?>
			<li class="alvaro-comment" id="comment-<?php comment_ID(); ?>">
				<div class="alvaro-one-comment">
					<?php if ( $args['avatar_size'] != 0 ) { $avatar = get_avatar( $comment, 64 ); } ?>
					<div class="comment-body-wrapper <?php echo !$avatar ? 'no-avatar' : ''; ?>">
						<?php echo wp_kses($avatar, array('img' => array('alt' => array(), 'src' => array(), 'srcset' => array(), 'class' => array(), 'width' => array(), 'height' => array()))); ?>
						<div class="comment-date">
							<?php comment_date( get_option( 'date_format' ) );?> at <?php comment_date( get_option( 'time_format' ) );?>
						</div>

						<div class="comment-meta">
							<?php comment_author_link(); ?>
							<span><?php esc_html_e( 'says', 'alvaro' ); ?></span>
						</div>

						<div class="small-separator"></div>
						
						<?php if( $this->page_layout['comments-as-reviews'] === true ){ ?>
							<div class="comment-rating"><?php echo wp_kses_post( $this->get_rating_html('', '', $comment_rating) ); ?></div>
						<?php } ?>

						<div class="comment-body">
							<?php comment_text(); ?>
						</div>

						<?php if( $this->page_layout['comments-as-reviews'] !== true ) { ?>
							<?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth'], 'reply_text' => esc_html__('Reply', 'alvaro')))) ?>
						<?php } ?>
						<?php if( current_user_can('edit_comment') ) { ?>
							<?php edit_comment_link( esc_html__( 'Edit', 'alvaro' ) ); ?>
						<?php } ?>
					</div>
				</div>
		<?php
		}

		public function alvaro_get_search_form($placeholder)
		{
		?>
			<form role="search" method="get" class="searchform" action="<?php echo esc_url( home_url( '/' ) ); ?>">
				<div>
					<input type="text" value="<?php echo esc_attr( get_search_query() ); ?>" name="s" id="s" placeholder="<?php echo esc_attr( $placeholder ); ?>" />
					<button id="searchsubmit"></button>
				</div>
			</form>
		<?php
		}

		public function excerpt_length( $length )
		{
			return 20;
		}

		public function save_rating( $commentID )
		{
			// Save rating against comment
			add_comment_meta($commentID, '_rating', (int)$_REQUEST['rating'], true);
		}

		public function get_rating( $post_id=0, $return="nb" )
		{
			$comment_array = get_approved_comments( $post_id );

			if( $return == 'votes' ){
				return count($comment_array);
			}
			$rate = 0;
			if( count($comment_array) > 0 ){
				foreach ($comment_array as $comment) {
					$rating = (int) get_comment_meta($comment->comment_ID, '_rating', true);
					$rate = $rate + $rating;
				}

				$rate = number_format( $rate / count($comment_array), 2 );
			}

			return $rate;
		}

		public function get_rating_html( $name='', $label="", $default=-1 )
		{
			$html = array();

			$html[] = '<div class="alvaro-rating-container ' . ( $default > -1 ? 'alvaro-rating-block' : '' ) . '' . ( trim($name) == "" ? ' alvaro-rating-readonly' : '' ) . '">';
			
			if( trim( $name != "" ) ) $html[] = 	'<input type="hidden" name="' . ( $name ) . '" />';
			if( trim( $label != "" ) ) $html[] = 	'<label>' . ( $label ) . '</label>';
			$html[] = 	'<div class="alvaro-rating-container-bk">';

			for( $cc = 0; $cc < 5; $cc++ ){

				if( $cc < $default ){
					$html[] = 	'<i class="fa fa-star"></i>';
				}else{
					$html[] = 	'<i class="fa fa-star-o"></i>';
				}
			}
			$html[] = 	'</div>';
			$html[] = '</div>';

			return implode( "\n", $html );
		}
		
		public function update_page_layout()
		{
			$page_id     = get_queried_object_id();
			$this->page_layout = array();
			if( (int) $page_id > 0 ){

				$this->page_layout['hide_page_title'] = get_post_meta( $page_id, '_alvaro_hide_page_title', true );
				$this->page_layout['comments-as-reviews'] = false;
				$this->page_layout['rev_slider_alias'] 	= get_post_meta( $page_id, '_alvaro_rev_slider_alias', true );
			}
		}

		public function delete_all_between($beginning, $end, $string) 
		{
			return preg_replace('#(' . ( $beginning ) . ').*?(' . ( $end ) . ')#', '$1$2', $string);
		}

		public function default_avatar( $avatar_defaults ) 
		{
			$new_avatar_url = get_template_directory_uri() . '/img/default_avatar.jpg';
			$avatar_defaults[$new_avatar_url] = esc_html__('Movie Default Avatar', 'alvaro');
			return $avatar_defaults;
		}

		public function display_breadcrumbs()
		{
			$text['home']     = esc_html__('Home', 'alvaro'); // text for the 'Home' link
			$text['category'] = esc_html__('Archive by Category "%s"', 'alvaro'); // text for a category page
			$text['tax'] 	  = esc_html__('Archive for "%s"', 'alvaro'); // text for a taxonomy page
			$text['search']   = esc_html__('Search Results for "%s" Query', 'alvaro'); // text for a search results page
			$text['tag']      = esc_html__('Posts Tagged "%s"', 'alvaro'); // text for a tag page
			$text['author']   = esc_html__('Articles Posted by %s', 'alvaro'); // text for an author page
			$text['404']      = esc_html__('Error 404', 'alvaro'); // text for the 404 page
		
			$showCurrent = 1; // 1 - show current post/page title in breadcrumbs, 0 - don't show
			$before      = '<li class="current">'; // tag before the current crumb
			$after       = '</li>'; // tag after the current crumb
			$linkAttr = '';
			$delimiter = '<i class="fa fa-angle-right" aria-hidden="true"></i>'; //'&rsaquo;';
			$cats = '';
			/* === END OF OPTIONS === */
		
			global $post;
			$homeLink = esc_url( home_url('/') );
			$linkBefore = '<li>';
			$linkAfter = '</li>';
			$link = $linkBefore . '<a' . $linkAttr . ' href="%1$s">%2$s</a>' . $linkAfter;

			echo '<div class="alvaro-breadcrumbs-container">';
			echo '<ul class="alvaro-breadcrumbs-list">' . (!is_home() && !is_front_page() ? sprintf($link, $homeLink, $text['home']) . $delimiter : '');
			
			if ( is_category() ) {
				$thisCat = get_category(get_query_var('cat'), false);
				if ($thisCat->parent != 0) {
					$cats = get_category_parents($thisCat->parent, TRUE, $delimiter);
					$cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
					$cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
					echo wp_kses_post( $cats );
				}
				echo wp_kses_post( $before . sprintf($text['category'], single_cat_title('', false)) . $after );
	
			} elseif ( function_exists('is_product') && is_product() ) { 
				$terms = get_the_terms( $post->ID, 'product_cat' );
				if( $terms && count($terms) > 0 ){
					foreach ($terms as $term) {
						$product_cat_id = $term->term_id;
						$product_cat_slug = $term->slug;
						$product_cat_name = esc_attr($term->name);
						
						$cats .= '<li><a href="'. esc_url(get_site_url() . '/product-category/' . $product_cat_slug) .'">'.$product_cat_name.'</a></li>';	
						$cats .= '<li><a href="'. esc_url(get_permalink()) .'">'. esc_attr($post->post_title) .'</a></li>';			
						echo wp_kses_post( $cats );
						break;
					}
				}
			} elseif( is_tax() ){
				
				$thisCat = get_category(get_query_var('cat'), false);
				
				if ( !isset($thisCat->errors) && $thisCat->parent != 0) {
					$cats = get_category_parents($thisCat->parent, TRUE, $delimiter);
					$cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
					$cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
					echo wp_kses_post( $cats );
				}
				echo wp_kses_post( $before . sprintf($text['tax'], single_cat_title('', false)) . $after );
			
			} elseif ( is_search() ) {
				echo wp_kses_post( $before . sprintf($text['search'], get_search_query()) . $after );
	
			} elseif ( is_day() ) {
				echo sprintf($link, get_year_link(get_the_time('Y')), get_the_time('Y')) . $delimiter;
				echo sprintf($link, get_month_link(get_the_time('Y'),get_the_time('m')), get_the_time('F')) . $delimiter;
				echo wp_kses_post( $before . get_the_time('d') . $after );
	
			} elseif ( is_month() ) {
				echo sprintf($link, get_year_link(get_the_time('Y')), get_the_time('Y')) . $delimiter;
				echo wp_kses_post( $before . get_the_time('F') . $after );
	
			} elseif ( is_year() ) {
				echo wp_kses_post( $before . get_the_time('Y') . $after );
	
			} elseif ( is_single() && !is_attachment() ) {
				if ( get_post_type() != 'post' ) {
					$post_type = get_post_type_object(get_post_type());
					$slug = $post_type->rewrite; 
					printf($link, esc_url( $homeLink . '/' . $slug['slug'] . '/'), $post_type->labels->singular_name );
					if ($showCurrent == 1) echo wp_kses_post( $delimiter . $before . get_the_title() . $after );
				} else {
					$cat = get_the_category(); $cat = $cat[0];
					$cats = get_category_parents($cat, TRUE, $delimiter);
					if ($showCurrent == 0) $cats = preg_replace("#^(.+)$delimiter$#", "$1", $cats);
					$cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
					$cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
					echo wp_kses_post( $cats );
					if ($showCurrent == 1) echo wp_kses_post( get_the_title() != '' ? ($before . get_the_title() . $after) : '' );
				}
	
			} elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() ) {
				$post_type = get_post_type_object(get_post_type());
				if( isset($post_type) )
					echo wp_kses_post( $before . esc_attr($post_type->labels->singular_name) . $after );

			} elseif ( is_attachment() ) {
				$parent = get_post($post->post_parent);
				$cat = get_the_category($parent->ID); $cat = $cat[0];
				$cats = get_category_parents($cat, TRUE, $delimiter);
				$cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
				$cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
				echo wp_kses_post( $cats );
				printf($link, esc_url(get_permalink($parent)), $parent->post_title);
				if ($showCurrent == 1) echo wp_kses_post( $delimiter . $before . get_the_title() . $after );
	
			} elseif ( is_page() && !$post->post_parent ) {
				if ($showCurrent == 1) echo wp_kses_post( $before . get_the_title() . $after );
	
			} elseif ( is_page() && $post->post_parent ) {
				$parent_id  = $post->post_parent;
				$breadcrumbs = array();
				while ($parent_id) {
					$page = get_page($parent_id);
					$breadcrumbs[] = sprintf($link, esc_url(get_permalink($page->ID)), get_the_title($page->ID));
					$parent_id  = $page->post_parent;
				}
				$breadcrumbs = array_reverse($breadcrumbs);
				for ($i = 0; $i < count($breadcrumbs); $i++) {
					echo wp_kses_post( $breadcrumbs[$i] );
					if ($i != count($breadcrumbs)-1) echo wp_kses_post( $delimiter );
				}
				if ($showCurrent == 1) echo wp_kses_post( get_the_title() != '' ? ($delimiter . $before . get_the_title() . $after) : '' );
	
			} elseif ( is_tag() ) {
				echo wp_kses_post( $before . sprintf($text['tag'], single_tag_title('', false)) . $after );
	
			} elseif ( is_author() ) {
				global $author;
				$userdata = get_userdata($author);
				echo wp_kses_post( $before . sprintf($text['author'], $userdata->display_name) . $after );
	
			} elseif ( is_404() ) {
				echo wp_kses_post( $before . $text['404'] . $after );
			}
	
			echo '</ul>';
			echo '</div>';
		}

		public function print_pagination( $wp_query=array() )
		{
			$html = array();
			if( $wp_query->post_count < $wp_query->found_posts ) {

				$big = 999999999; // need an unlikely integer
				$links = paginate_links( array(
					'base' => str_replace( $big, '%#%', html_entity_decode( get_pagenum_link( $big ) ) ),
					'format' => '?paged=%#%',
					'current' => max( 1, get_query_var('paged') ),
					'total' => $wp_query->max_num_pages,
					'prev_next' => false,
					'type' => 'list',
					'end_size'     => 3,
					'mid_size'     => 3
				) );


				$html[] = 	'<nav class="numbered-pagination">';
				$html[] = 		$links;
				$html[] = 		'<span class="alvaro-pages-no">' . esc_html__( 'Page ', 'alvaro' ) . ( max( 1, get_query_var('paged') ) ) . ' ' . esc_html__( 'of', 'alvaro' ) . ' ' . ( $wp_query->max_num_pages ) . '</span>';
				$html[] = 	'</nav>';

			}

			return implode( "\n", $html );
		}

		public function tag_cloud_filter($args = array()) {
		   $args['smallest'] = 15;
		   $args['largest'] = 15;
		   $args['unit'] = 'px';
		   return $args;
		}
		


		public function display_excerpt($limit) {
		  
		  $excerpt_output = explode(' ', get_the_excerpt(), $limit);
		  
		  if ( count( $excerpt_output ) >= $limit ) {
			array_pop($excerpt_output);
			$excerpt_output = implode(" ",$excerpt_output).'...';
		  } else {
			$excerpt_output = implode(" ",$excerpt_output);
		  }
			
		  $excerpt_output = preg_replace('`\[[^\]]*\]`','',$excerpt_output);
		  
		  return '<p>' . $excerpt_output . '</p>';
		}
		
		public function loop_columns() {
			return 3; // 3 products per row
		}
		
		public function custom_override_get_availability( $availability, $_product ) {
			if ( $_product->is_in_stock() ) {
				$availability['availability'] = esc_html__('In Stock', 'alvaro');
			}
			return $availability;
		}
		
		public function get_gallery_attachments(){
			global $post;
			
			$post_content = $post->post_content;
			preg_match('/\[gallery.*ids=.(.*).\]/', $post_content, $ids);
			$images_id = count($ids) > 0 ? explode(",", $ids[1]) : null;
			
			return $images_id;
		}
		
		public function get_link_url() {
			$content = get_the_content();
			$check_url = get_url_in_content( $content );
		
			return ( $check_url ) ? $check_url : apply_filters( 'the_permalink', get_permalink() );
		}

		public function wpb_author_info_box( $content ) {
 
			global $post;
			 
			// Detect if it is a single post with a post author
			if ( is_single() && isset( $post->post_author ) ) {
				 
				// Get author's display name 
				$display_name = get_the_author_meta( 'display_name', $post->post_author );
				 
				// If display name is not available then use nickname as display name
				if ( empty( $display_name ) )
				$display_name = get_the_author_meta( 'nickname', $post->post_author );
				 
				// Get author's biographical information or description
				$user_description = get_the_author_meta( 'user_description', $post->post_author );
				 
				// Get author's website URL 
				$user_website = get_the_author_meta('url', $post->post_author);
				 
				// Get link to the author archive page
				$user_posts = get_author_posts_url( get_the_author_meta( 'ID' , $post->post_author));
				  
				if ( ! empty( $display_name ) )
				 
				$author_details = '<p class="author_name">About ' . $display_name . '</p>';
				 
				if ( ! empty( $user_description ) )
				// Author avatar and bio
				 
				$author_details .= '<p class="author_details">' . get_avatar( get_the_author_meta('user_email') , 90 ) . nl2br( $user_description ). '</p>';
				 
				$author_details .= '<p class="author_links"><a href="'. $user_posts .'">View all posts by ' . $display_name . '</a>';  
				 
				// Check if author has a website in their profile
				if ( ! empty( $user_website ) ) {
				 
					// Display author website link
					$author_details .= ' | <a href="' . $user_website .'" target="_blank" rel="nofollow">Website</a></p>';
				 
				} else { 
					// if there is no author website then just close the paragraph
					$author_details .= '</p>';
				}
				 
				// Pass all this info to post content  
				$content = $content . '<footer class="author_bio_section" >' . $author_details . '</footer>';
			}
			return $content;
		}
	}
}

function alvaro(){
	return alvaro::getInstance();
}
alvaro();
