<?php
/*
Plugin Name: Alvaro - Visual Composer Addon
Plugin URI: http://wpbakery.com/vc
Description: Extend Visual Composer with Alvaro theme shortcodes.
Version: 1.0
Author: AA-Team
Author URI: http://www.aa-team.com
License: GPLv2 or later
*/

/*
This example/starter plugin can be used to speed up Visual Composer plugins creation process.
More information can be found here: http://kb.wpbakery.com/index.php?title=Category:Visual_Composer
*/

// don't load directly
if (!defined('ABSPATH')) die('-1');

class VCExtendAddonClass {
    function __construct() {
        // We safely integrate with VC with this hook
        add_action( 'init', array( $this, 'integrateWithVC' ) );
    }
	
	/**
	 * monosocial icons from drinchev.github.io/monosocialiconsfont
	 *
	 * @param $icons - taken from filter - vc_map param field settings['source']
	 *     provided icons (default empty array). If array categorized it will
	 *     auto-enable category dropdown
	 *
	 * @since 4.4
	 * @return array - of icons for iconpicker, can be categorized, or not.
	 */
	public function vc_iconpicker_type_icomoon( $icons ) {
		$icomoon = json_decode( file_get_contents( plugin_dir_path( __FILE__ ) . 'assets/icomoon-icons.json' ) );
		return array_merge( $icons, $icomoon );
	}
	
	public function icomoon_vc_iconpicker_base_register_css(){
	    wp_register_style( 'vc-icomoon', plugins_url('assets/icomoon.css', __FILE__) );
	}
	
	public function icomoon_vc_iconpicker_editor_jscss(){
	    wp_enqueue_style( 'vc-icomoon' );
	}
		
	public function vc_icon_element_fonts_enqueue( $font ) {
		switch ( $font ) {
			case 'icomoon': wp_enqueue_style( 'vc-icomoon' );
		}
	}

    public function integrateWithVC() {
        // Check if Visual Composer is installed
        if ( ! defined( 'WPB_VC_VERSION' ) ) {
            // Display notice that Visual Compser is required
            add_action('admin_notices', array( $this, 'showVcVersionNotice' ));
            return;
        }
		
    	add_shortcode( 'vc_alvaro_fancy_heading', array( $this, 'alvaro_fancy_heading') );
		add_shortcode( 'vc_alvaro_section_heading', array( $this, 'alvaro_section_heading') );
		add_shortcode( 'vc_alvaro_fish_species_slider', array( $this, 'alvaro_fish_species_slider') );
		add_shortcode( 'vc_alvaro_camping_locations_slider', array( $this, 'alvaro_camping_locations_slider') );
		add_shortcode( 'vc_alvaro_camping_locations_list', array( $this, 'alvaro_camping_locations_list') );
		add_shortcode( 'vc_alvaro_blog_list', array( $this, 'alvaro_blog_list') );
		add_shortcode( 'vc_alvaro_image_hotspot', array( $this, 'alvaro_image_hotspot') );
		add_shortcode( 'vc_alvaro_google_maps', array( $this, 'alvaro_google_maps') );
		add_shortcode( 'vc_alvaro_gallery', array( $this, 'alvaro_custom_gallery') );
		add_shortcode( 'vc_alvaro_shop_title_preview', array( $this, 'alvaro_shop_title_preview') );

		/**
		 * Register Backend and Frontend CSS Styles
		 */
		add_action( 'vc_base_register_front_css', array( $this, 'icomoon_vc_iconpicker_base_register_css' ) );
		add_action( 'vc_base_register_admin_css', array( $this, 'icomoon_vc_iconpicker_base_register_css' ) );
		
		/**
		 * Enqueue Backend and Frontend CSS Styles
		 */
		add_action( 'vc_backend_editor_enqueue_js_css', array( $this, 'icomoon_vc_iconpicker_editor_jscss' ) );
		add_action( 'vc_frontend_editor_enqueue_js_css', array( $this, 'icomoon_vc_iconpicker_editor_jscss' ) );

		add_filter( 'vc_iconpicker-type-icomoon', array( $this, 'vc_iconpicker_type_icomoon' ) );
		add_action( 'vc_enqueue_font_icon_element' , array( $this, 'vc_icon_element_fonts_enqueue' ) );
		
        // Register CSS and JS
        add_action( 'wp_enqueue_scripts', array( $this, 'loadCssAndJs' ) );
		
        /*
        Add your Visual Composer logic here.
        Lets call vc_map function to "register" our custom shortcode within Visual Composer interface.

        More info: http://kb.wpbakery.com/index.php?title=Vc_map
        */

        vc_add_shortcode_param( 'html_description', 'html_description_settings_field' );
		function html_description_settings_field( $settings, $value ) {
		   return '<div class="html_description_block">' . ( $value ) . '</div>'; // This is html markup that will be outputted in content elements edit form
		}
		
		vc_map( array(
            "name" => __("Alvaro Fancy Heading", 'vc_extend'),
            "description" => __("Alvaro Fancy Heading", 'vc_extend'),
            "base" => "vc_alvaro_fancy_heading",
            "class" => "",
            "controls" => "full",
            "icon" => plugins_url('assets/images/icons/alvaro_icon.png', __FILE__), // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
            "category" => __('Alvaro', 'vc_extend'),
            //'admin_enqueue_js' => array(plugins_url('assets/vc_extend.js', __FILE__)), // This will load js file in the VC backend editor
            //'admin_enqueue_css' => array(plugins_url('assets/vc_extend_admin.css', __FILE__)), // This will load css file in the VC backend editor
            "params" => array(
				array(
					"type" => "textfield",
					"holder" => "",
					"class" => "",
					"heading" => __("Title", 'vc_extend'),
					"param_name" => "title",
					"value" => __("Fishing Species", 'vc_extend'),
					"description" => __("Alvaro Fancy Heading Title", 'vc_extend')
				),
				
				array(
			      "type"        => "dropdown",
			      "heading"     => __("Fancy Heading Icon"),
			      "param_name"  => "fancy_heading_icon",
			      "admin_label" => true,
			      "value"       => array(
			        'yes'   => 'yes',
			        'no'   => 'no',
			      ),
			      "std"         => 'no',
			      "description" => __("Display heading icon")
		      ),

		      array(
			      "type"        => "dropdown",
			      "heading"     => __("Fancy Heading Style"),
			      "param_name"  => "fancy_heading_style",
			      "admin_label" => true,
			      "value"       => array(
			        'Style 1'   => 'Style 1',
			        'Style 2'   => 'Style 2',
			      ),
			      "std"         => 'Style 1',
			      "description" => __("Fancy heading style")
		      ),

		      array(
			      "type"        => "dropdown",
			      "heading"     => __("Fancy Heading Icon Type"),
			      "param_name"  => "fancy_heading_icon_type",
			      "admin_label" => true,
			      "value"       => array(
			        'font awesome'   => 'font awesome',
			        'icomoon'   => 'icomoon',
			        'manual upload'   => 'manual upload',
			      ),
			      "std"         => 'font awesome',
			      "description" => __("Fancy Heading Icon Type")
		      ),

		      array(
                  "type" => "iconpicker",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Fancy Heading Font Awesome Icon", 'vc_extend'),
                  "param_name" => "font_awesome_icon",
                  "value" => __("fa fa-html5", 'vc_extend'),
                  "description" => __("Fancy Heading Font Awesome Icon", 'vc_extend'),
              ),
              
			  array(
                  "type" => "iconpicker",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Fancy Heading Moon Icon", 'vc_extend'),
                  "param_name" => "ico_moon_icon",
                  "settings" => array( "type" => "icomoon" ),
                  "value" => __("icon icon-home", 'vc_extend'),
                  "description" => __("Fancy Heading IcoMoon", 'vc_extend'),
              ),

			  array(
                  "type" => "attach_image",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Alvaro Fancy Heading Icon URL", 'vc_extend'),
                  "param_name" => "icon_url",
                  "description" => __("Alvaro Fancy Heading Icon URL", 'vc_extend')
              ),

              array(
			      "type"        => "dropdown",
			      "heading"     => __("Text align"),
			      "param_name"  => "text_align",
			      "admin_label" => true,
			      "value"       => array(
			        'left'   => 'left',
			        'right'   => 'right',
			        'center'  => 'center',
			        'justify' => 'justify'
			      ),
			      "std"         => 'center',
			      "description" => __("Text Align")
		      ),
		      
		      array(
	              "type" => "textfield",
	              "holder" => "",
	              "class" => "",
	              "heading" => __("Font Size (in px)", 'vc_extend'),
	              "param_name" => "font_size",
	              "value" => __("", 'vc_extend'),
	              "description" => __("Alvaro Fancy Heading Font Size", 'vc_extend')
			  ),

		      array(
	              "type" => "colorpicker",
	              "holder" => "",
	              "class" => "",
	              "heading" => __("Text color", 'vc_extend'),
	              "param_name" => "color",
	              "value" => '#282828',
	              "description" => __("Choose text color. Default is #282828", 'vc_extend')
			  ),
			  
				array(
					"type" => "textfield",
					"holder" => "",
					"class" => "",
					"heading" => __("Line Width (in %)", 'vc_extend'),
					"param_name" => "line_width",
					"value" => __("80", 'vc_extend'),
					"description" => __("Alvaro Fancy Heading Icon back line", 'vc_extend')
				),
            )
        ) );
		
		vc_map( array(
            "name" => __("Alvaro Section Heading", 'vc_extend'),
            "description" => __("Alvaro Section Heading", 'vc_extend'),
            "base" => "vc_alvaro_section_heading",
            "class" => "",
            "controls" => "full",
            "icon" => plugins_url('assets/images/icons/alvaro_icon.png', __FILE__), // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
            "category" => __('Alvaro', 'vc_extend'),
            //'admin_enqueue_js' => array(plugins_url('assets/vc_extend.js', __FILE__)), // This will load js file in the VC backend editor
            //'admin_enqueue_css' => array(plugins_url('assets/vc_extend_admin.css', __FILE__)), // This will load css file in the VC backend editor
            "params" => array(
				array(
					"type" => "textfield",
					"holder" => "",
					"class" => "",
					"heading" => __("Title", 'vc_extend'),
					"param_name" => "title",
					"value" => __("Lorem Ipsum", 'vc_extend'),
					"description" => __("Alvaro Section Heading Title", 'vc_extend')
				),
				array(
					"type"        => "dropdown",
					"heading"     => __("Text align"),
					"param_name"  => "text_align",
					"admin_label" => true,
					"value"       => array(
						'left'   => 'left',
						'right'   => 'right',
						'center'  => 'center',
						'justify' => 'justify'
					),
					"std"         => 'left',
					"description" => __("Text Align")
				),

            )
        ) );
		
		vc_map( array(
            "name" => __("Alvaro Image Hotspot", 'vc_extend'),
            "description" => __("Alvaro Image Hotspot", 'vc_extend'),
            "base" => "vc_alvaro_image_hotspot",
            "class" => "",
            "controls" => "full",
            "icon" => plugins_url('assets/images/icons/alvaro_icon.png', __FILE__), // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
            "category" => __('Alvaro', 'vc_extend'),
            //'admin_enqueue_js' => array(plugins_url('assets/vc_extend.js', __FILE__)), // This will load js file in the VC backend editor
            //'admin_enqueue_css' => array(plugins_url('assets/vc_extend_admin.css', __FILE__)), // This will load css file in the VC backend editor
            "params" => array(
			  array(
                  "type" => "attach_image",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Alvaro Hotspot Image URL", 'vc_extend'),
                  "param_name" => "hotspot_image_url",
                  "description" => __("Alvaro Hotspot Image URL", 'vc_extend')
              ),
              
              array(
	              "type" => "textfield",
	              "holder" => "",
	              "class" => "",
	              "heading" => __("Intro Title", 'vc_extend'),
	              "param_name" => "hotspot_intro_title",
	              "value" => __("fishing trip", 'vc_extend'),
	              "description" => __("Alvaro Hotspot Intro Title", 'vc_extend')
              ),

			  array(
	              "type" => "textfield",
	              "holder" => "",
	              "class" => "",
	              "heading" => __("Title", 'vc_extend'),
	              "param_name" => "hotspot_title",
	              "value" => __("Danube", 'vc_extend'),
	              "description" => __("Alvaro Hotspot Title", 'vc_extend')
              ),
              
			  array(
	              "type" => "textfield",
	              "holder" => "",
	              "class" => "",
	              "heading" => __("Subtitle", 'vc_extend'),
	              "param_name" => "hotspot_subtitle",
	              "value" => __("8 days / 7 nights", 'vc_extend'),
	              "description" => __("Alvaro Hotspot Subtitle", 'vc_extend')
              ),
              
			  array(
	              "type" => "textarea_html",
	              "holder" => "",
	              "class" => "",
	              "heading" => __("Content", 'vc_extend'),
	              "param_name" => "content",
	              "value" => __("", 'vc_extend'),
	              "description" => __("Alvaro Hotspot Content", 'vc_extend')
              ),
              
			  array(
	              "type" => "textfield",
	              "holder" => "",
	              "class" => "",
	              "heading" => __("Price", 'vc_extend'),
	              "param_name" => "hotspot_price",
	              "value" => __("499.99", 'vc_extend'),
	              "description" => __("Alvaro Hotspot Price", 'vc_extend')
              ),
              
			  array(
	              "type" => "textfield",
	              "holder" => "",
	              "class" => "",
	              "heading" => __("Price Coin", 'vc_extend'),
	              "param_name" => "hotspot_coin",
	              "value" => __("$", 'vc_extend'),
	              "description" => __("Alvaro Hotspot Price Coin", 'vc_extend')
              ),

			  array(
	              "type" => "textfield",
	              "holder" => "",
	              "class" => "",
	              "heading" => __("View More Link", 'vc_extend'),
	              "param_name" => "hotspot_viewmore_link",
	              "value" => __("#", 'vc_extend'),
	              "description" => __("Alvaro Hotspot Viewmore link", 'vc_extend')
              ),
              
			  // params group
            array(
                'type' => 'param_group',
                'value' => '',
                'param_name' => 'hotspots',
                // Note params is mapped inside param-group:
                'params' => array(
                    array(
                        'type' => 'textfield',
                        'value' => '',
                        'heading' => 'Hotspot X',
                        'param_name' => 'hotspot_x',
                    ),
                    array(
                        'type' => 'textfield',
                        'value' => '',
                        'heading' => 'Hotspot Y',
                        'param_name' => 'hotspot_y',
                    ),
                    array(
                        'type' => 'textfield',
                        'value' => '',
                        'heading' => 'Hotspot Title',
                        'param_name' => 'hotspot_title',
                    ),
                    array(
                        'type' => 'attach_image',
                        'value' => '',
                        'heading' => 'Hotspot Icon',
                        'param_name' => 'hotspot_icon',
                    ),
                    array(
                        'type' => 'attach_image',
                        'value' => '',
                        'heading' => 'Hotspot Image',
                        'param_name' => 'hotspot_image',
                    ),
                )
            )

            )
        ) );
		
		vc_map( array(
            "name" => __("Fish Species Slider", 'vc_extend'),
            "description" => __("Alvaro Fish Species Slider", 'vc_extend'),
            "base" => "vc_alvaro_fish_species_slider",
            "class" => "",
            "controls" => "full",
            "icon" => plugins_url('assets/images/icons/alvaro_icon.png', __FILE__), // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
            "category" => __('Alvaro', 'vc_extend'),
            //'admin_enqueue_js' => array(plugins_url('assets/vc_extend.js', __FILE__)), // This will load js file in the VC backend editor
            //'admin_enqueue_css' => array(plugins_url('assets/vc_extend_admin.css', __FILE__)), // This will load css file in the VC backend editor
            "params" => array(
            	array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Number of fish species per page", 'vc_extend'),
                  "param_name" => "per_page",
                  "value" => __("10", 'vc_extend'),
                  "description" => __("", 'vc_extend')
              ),

			  array(
		      "type"        => "dropdown",
		      "heading"     => __("Order by"),
		      "param_name"  => "orderby",
		      "admin_label" => true,
		      "value"       => array(
		        'post_date'   => 'post_date',
		        'ID'   => 'ID',
		        'author'   => 'author',
		        'title'   => 'title',
		        'name'   => 'name',
		        'type'   => 'type',
		        'modified'   => 'modified',
		        'parent'   => 'parent',
		        'rand'   => 'rand',
		        'comment_count'   => 'comment_count',
		        'menu_order'   => 'menu_order',
		      ),
		      "std"         => 'post_date',
		      "description" => __("Order slides by")
		      ),

			array(
		      "type"        => "dropdown",
		      "heading"     => __("Order"),
		      "param_name"  => "order",
		      "admin_label" => true,
		      "value"       => array(
		        'ASC'   => 'ASC',
		        'DESC'   => 'DESC',
		      ),
		      "std"         => 'DESC',
		      "description" => __("")
		      ),

			  array(
			      "type"        => "dropdown",
			      "heading"     => __("Autoplay"),
			      "param_name"  => "autoplay",
			      "admin_label" => true,
			      "value"       => array(
				        'true'   => 'true',
				        'false'   => 'false',
			      ),
			      "std"         => 'false',
			      "description" => __("")
		      ),

			   array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Items", 'vc_extend'),
                  "param_name" => "items",
                  "value" => __("3", 'vc_extend'),
                  "description" => __("Items", 'vc_extend')
              ),

			  array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Items Desktop", 'vc_extend'),
                  "param_name" => "items_desktop",
                  "value" => __("3", 'vc_extend'),
                  "description" => __("Items Desktop", 'vc_extend')
              ),

              array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Items Desktop Small", 'vc_extend'),
                  "param_name" => "items_desktop_small",
                  "value" => __("3", 'vc_extend'),
                  "description" => __("Items Desktop Small", 'vc_extend')
              ),

			  array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Items Tablet", 'vc_extend'),
                  "param_name" => "items_tablet",
                  "value" => __("2", 'vc_extend'),
                  "description" => __("Items Tablet", 'vc_extend')
              ),

			  array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Items Mobile", 'vc_extend'),
                  "param_name" => "items_mobile",
                  "value" => __("1", 'vc_extend'),
                  "description" => __("Items Mobile", 'vc_extend')
              ),

              array(
			      "type"        => "dropdown",
			      "heading"     => __("Pagination"),
			      "param_name"  => "pagination",
			      "admin_label" => true,
			      "value"       => array(
				        'true'   => 'true',
				        'false'   => 'false',
			      ),
			      "std"         => 'true',
			      "description" => __("")
		      ),
		      
			  array(
			      "type"        => "dropdown",
			      "heading"     => __("Navigation"),
			      "param_name"  => "navigation",
			      "admin_label" => true,
			      "value"       => array(
				        'true'   => 'true',
				        'false'   => 'false',
			      ),
			      "std"         => 'true',
			      "description" => __("")
		      ),

            )
        ) );
		
		vc_map( array(
            "name" => __("Camping Locations Slider", 'vc_extend'),
            "description" => __("Alvaro Camping Locations Slider", 'vc_extend'),
            "base" => "vc_alvaro_camping_locations_slider",
            "class" => "",
            "controls" => "full",
            "icon" => plugins_url('assets/images/icons/alvaro_icon.png', __FILE__), // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
            "category" => __('Alvaro', 'vc_extend'),
            //'admin_enqueue_js' => array(plugins_url('assets/vc_extend.js', __FILE__)), // This will load js file in the VC backend editor
            //'admin_enqueue_css' => array(plugins_url('assets/vc_extend_admin.css', __FILE__)), // This will load css file in the VC backend editor
            "params" => array(
            	array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Number of camping locations per page", 'vc_extend'),
                  "param_name" => "per_page",
                  "value" => __("10", 'vc_extend'),
                  "description" => __("", 'vc_extend')
              ),

			  array(
		      "type"        => "dropdown",
		      "heading"     => __("Order by"),
		      "param_name"  => "orderby",
		      "admin_label" => true,
		      "value"       => array(
		        'post_date'   => 'post_date',
		        'ID'   => 'ID',
		        'author'   => 'author',
		        'title'   => 'title',
		        'name'   => 'name',
		        'type'   => 'type',
		        'modified'   => 'modified',
		        'parent'   => 'parent',
		        'rand'   => 'rand',
		        'comment_count'   => 'comment_count',
		        'menu_order'   => 'menu_order',
		      ),
		      "std"         => 'post_date',
		      "description" => __("Order slides by")
		      ),

			array(
		      "type"        => "dropdown",
		      "heading"     => __("Order"),
		      "param_name"  => "order",
		      "admin_label" => true,
		      "value"       => array(
		        'ASC'   => 'ASC',
		        'DESC'   => 'DESC',
		      ),
		      "std"         => 'DESC',
		      "description" => __("")
		      ),

			  array(
			      "type"        => "dropdown",
			      "heading"     => __("Autoplay"),
			      "param_name"  => "autoplay",
			      "admin_label" => true,
			      "value"       => array(
				        'true'   => 'true',
				        'false'   => 'false',
			      ),
			      "std"         => 'false',
			      "description" => __("")
		      ),

			   array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Items", 'vc_extend'),
                  "param_name" => "items",
                  "value" => __("3", 'vc_extend'),
                  "description" => __("Items", 'vc_extend')
              ),

			  array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Items Desktop", 'vc_extend'),
                  "param_name" => "items_desktop",
                  "value" => __("3", 'vc_extend'),
                  "description" => __("Items Desktop", 'vc_extend')
              ),

              array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Items Desktop Small", 'vc_extend'),
                  "param_name" => "items_desktop_small",
                  "value" => __("3", 'vc_extend'),
                  "description" => __("Items Desktop Small", 'vc_extend')
              ),

			  array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Items Tablet", 'vc_extend'),
                  "param_name" => "items_tablet",
                  "value" => __("2", 'vc_extend'),
                  "description" => __("Items Tablet", 'vc_extend')
              ),

			  array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Items Mobile", 'vc_extend'),
                  "param_name" => "items_mobile",
                  "value" => __("1", 'vc_extend'),
                  "description" => __("Items Mobile", 'vc_extend')
              ),

              array(
			      "type"        => "dropdown",
			      "heading"     => __("Pagination"),
			      "param_name"  => "pagination",
			      "admin_label" => true,
			      "value"       => array(
				        'true'   => 'true',
				        'false'   => 'false',
			      ),
			      "std"         => 'true',
			      "description" => __("")
		      ),
		      
			  array(
			      "type"        => "dropdown",
			      "heading"     => __("Navigation"),
			      "param_name"  => "navigation",
			      "admin_label" => true,
			      "value"       => array(
				        'true'   => 'true',
				        'false'   => 'false',
			      ),
			      "std"         => 'true',
			      "description" => __("")
		      ),

            )
        ) );
		
		vc_map( array(
            "name" => __("Camping Locations List", 'vc_extend'),
            "description" => __("Alvaro Camping Locations List", 'vc_extend'),
            "base" => "vc_alvaro_camping_locations_list",
            "class" => "",
            "controls" => "full",
            "icon" => plugins_url('assets/images/icons/alvaro_icon.png', __FILE__), // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
            "category" => __('Alvaro', 'vc_extend'),
            //'admin_enqueue_js' => array(plugins_url('assets/vc_extend.js', __FILE__)), // This will load js file in the VC backend editor
            //'admin_enqueue_css' => array(plugins_url('assets/vc_extend_admin.css', __FILE__)), // This will load css file in the VC backend editor
            "params" => array(
            	array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Number of camping locations per page", 'vc_extend'),
                  "param_name" => "per_page",
                  "value" => __("10", 'vc_extend'),
                  "description" => __("", 'vc_extend')
              ),

			  array(
		      "type"        => "dropdown",
		      "heading"     => __("Order by"),
		      "param_name"  => "orderby",
		      "admin_label" => true,
		      "value"       => array(
		        'post_date'   => 'post_date',
		        'ID'   => 'ID',
		        'author'   => 'author',
		        'title'   => 'title',
		        'name'   => 'name',
		        'type'   => 'type',
		        'modified'   => 'modified',
		        'parent'   => 'parent',
		        'rand'   => 'rand',
		        'comment_count'   => 'comment_count',
		        'menu_order'   => 'menu_order',
		      ),
		      "std"         => 'post_date',
		      "description" => __("Order slides by")
		      ),

			array(
		      "type"        => "dropdown",
		      "heading"     => __("Order"),
		      "param_name"  => "order",
		      "admin_label" => true,
		      "value"       => array(
		        'ASC'   => 'ASC',
		        'DESC'   => 'DESC',
		      ),
		      "std"         => 'DESC',
		      "description" => __("")
		      ),
            )
        ) );
		
		vc_map( array(
            "name" => __("Alvaro Blog List", 'vc_extend'),
            "description" => __("Alvaro Blog List", 'vc_extend'),
            "base" => "vc_alvaro_blog_list",
            "class" => "",
            "controls" => "full",
            "icon" => plugins_url('assets/images/icons/alvaro_icon.png', __FILE__), // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
            "category" => __('Alvaro', 'vc_extend'),
            //'admin_enqueue_js' => array(plugins_url('assets/vc_extend.js', __FILE__)), // This will load js file in the VC backend editor
            //'admin_enqueue_css' => array(plugins_url('assets/vc_extend_admin.css', __FILE__)), // This will load css file in the VC backend editor
            "params" => array(
              array(
			      "type"        => "dropdown",
			      "heading"     => __("Blog columns number"),
			      "param_name"  => "blog_columms_no",
			      "admin_label" => true,
			      "value"       => array(
			        '1 column'   => '1',
			        '2 columns'   => '2'
			      ),
			      "std"         => '1',
			      "description" => __("Blog columns number")
		      ),
			  
              array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Blog posts per page", 'vc_extend'),
                  "param_name" => "per_page",
                  "value" => __("", 'vc_extend'),
                  "std"         => '10',
                  "description" => __("Blog posts per page", 'vc_extend')
              ),
              
			  array(
			      "type"        => "dropdown",
			      "heading"     => __("Order Blog Posts By"),
			      "param_name"  => "orderby",
			      "admin_label" => true,
			      "value"       => array(
				        'post_date'   => 'post_date',
				        'ID'   => 'ID',
				        'author'   => 'author',
				        'title'   => 'title',
				        'name'   => 'name',
				        'menu_order'   => 'menu_order',
			      ),
			      "std"         => 'post_date',
			      "description" => __("")
		      ),
		      
            )
        ) );
		
		vc_map( array(
            "name" => __("Alvaro Custom Google Maps", 'vc_extend'),
            "description" => __("Custom google maps", 'vc_extend'),
            "base" => "vc_alvaro_google_maps",
            "class" => "",
            "controls" => "full",
            "icon" => plugins_url('assets/images/icons/alvaro_icon.png', __FILE__), // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
            "category" => __('Alvaro', 'vc_extend'),
            //'admin_enqueue_js' => array(plugins_url('assets/vc_extend.js', __FILE__)), // This will load js file in the VC backend editor
            //'admin_enqueue_css' => array(plugins_url('assets/vc_extend_admin.css', __FILE__)), // This will load css file in the VC backend editor
            "params" => array(
              array(
                  "type" => "textfield",
                  "heading" => __("Google API Key", 'vc_extend'),
                  "param_name" => "api_key",
                  "std"         => '',
                  "description" => __('Get api key from <a href="https://developers.google.com/maps/documentation/javascript/get-api-key" target="_blank">here</a>', 'vc_extend')
              ),
			  array(
                  "type" => "textfield",
                  "heading" => __("Address", 'vc_extend'),
                  "param_name" => "address",
                  "std"         => '',
              ),
			  array(
                  "type" => "textfield",
                  "heading" => __("Zoom", 'vc_extend'),
                  "param_name" => "zoom",
                  "std"         => '12',
              ),
              array(
			      "type"        => "dropdown",
			      "heading"     => __("Hide Controls", "vc_extend"),
			      "param_name"  => "hide_controls",
			      "admin_label" => true,
			      "value"       => array(
			        __('YES', 'vc_extend')	=> 'yes',
			        __('NO', 'vc_extend')	=> 'no'
			      ),
			      "std"         => 'true',
			      "description" => __("Hide google map controls", 'vc_extend')
		      ),
			  array(
			      "type"        => "dropdown",
			      "heading"     => __("Black & White", "vc_extend"),
			      "param_name"  => "black_and_white",
			      "admin_label" => true,
			      "value"       => array(
			        __('YES', 'vc_extend')	=> 'yes',
			        __('NO', 'vc_extend')	=> 'no'
			      ),
			      "std"         => 'true',
			      "description" => __("Display map on black & white", 'vc_extend')
		      ),
			  array(
			      "type"        => "attach_image",
			      "heading"     => __("Marker", 'vc_extend'),
			      "param_name"  => "marker",
			      "admin_label" => true,
			      "description" => __("Marker icon to show on the map to your location", 'vc_extend')
		      ),
		      array(
                  "type" => "textfield",
                  "heading" => __("Width", 'vc_extend'),
                  "param_name" => "width",
                  "std"         => '100%',
              ),
			  array(
                  "type" => "textfield",
                  "heading" => __("Height", 'vc_extend'),
                  "param_name" => "height",
                  "std"         => '',
              ),
            )
        ) );
		
		vc_map( array(
			'name' => __( 'Alvaro Image Gallery', 'vc_extend' ),
			'base' => 'vc_alvaro_gallery',
			"icon" => plugins_url('assets/images/icons/alvaro_icon.png', __FILE__), // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
			'category' => __('Alvaro', 'vc_extend'),
			'description' => __( 'Responsive image gallery', 'vc_extend' ),
			'params' => array(
				array(
					'type' => 'textfield',
					'heading' => __( 'Widget title', 'vc_extend' ),
					'param_name' => 'title',
					'description' => __( 'Enter text used as widget title (Note: located above content element).', 'vc_extend' ),
				),
				array(
					'type' => 'textfield',
					'heading' => __( 'Gallery height', 'vc_extend' ),
					'param_name' => 'gallery_height',
					'description' => __( 'Enter gallery height (default 380px).', 'vc_extend' ),
				),
				array(
					"type" => "colorpicker",
					"holder" => "",
					"class" => "",
					"heading" => __("Background color", 'vc_extend'),
					"param_name" => "bg_color",
					"value" => '#101f3e',
					"description" => __("Choose gallery background color. Default is #101f3e. Used also in fullscreen mode", 'vc_extend')
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Border size', 'vc_extend' ),
					'param_name' => 'border_size',
					'value' => array_merge(array(''), range(0, 100)),
					'description' => __( 'Border color is given by the background you set above.', 'vc_extend' ),
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Enable Prev/Next buttons', 'vc_extend' ),
					'param_name' => 'prev_next_buttons',
					'value' => array(
						__( 'Yes', 'vc_extend' ) => 'yes',
						__( 'No', 'vc_extend' ) => 'no',
					),
					'description' => __( 'Enable previous / next navigation buttons.', 'vc_extend' ),
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Enable full screen toggle', 'vc_extend' ),
					'param_name' => 'fullscreen_toggle',
					'value' => array(
						__( 'Yes', 'vc_extend' ) => 'yes',
						__( 'No', 'vc_extend' ) => 'no',
					),
					'description' => __( 'Enable the fullscreen toggle button.', 'vc_extend' ),
				),
				/*array(
					'type' => 'dropdown',
					'heading' => __( 'Type', 'vc_extend' ),
					'param_name' => 'type',
					'value' => array(
						__( 'Fade', 'vc_extend' ) => 'fading',
						__( 'Slide', 'vc_extend' ) => 'sliding',
					),
					'description' => __( 'Select type.', 'vc_extend' ),
				),*/
				array(
					'type' => 'dropdown',
					'heading' => __( 'Has thumbnail navigation', 'vc_extend' ),
					'param_name' => 'has_thumb_nav_slider',
					'value' => array(
						__( 'Yes', 'vc_extend' ) => 'yes',
						__( 'No', 'vc_extend' ) => 'no',
					),
					'description' => __( 'Display a thumbnail navigation for the gallery.', 'vc_extend' ),
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Auto rotate', 'vc_extend' ),
					'param_name' => 'interval',
					'value' => array(
						3,
						5,
						10,
						15,
						__( 'Disable', 'vc_extend' ) => 0,
					),
					'description' => __( 'Auto rotate slides each X seconds.', 'vc_extend' ),
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Stop on hover?', 'vc_extend' ),
					'param_name' => 'stop_on_hover',
					'value' => array(
						__( 'Yes', 'vc_extend' ) => 'yes',
						__( 'No', 'vc_extend' ) => 'no',
					),
					'description' => __( 'Stops the auto rotate on hover over the image gallery', 'vc_extend' ),
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Image source', 'vc_extend' ),
					'param_name' => 'source',
					'value' => array(
						__( 'Media library', 'vc_extend' ) => 'media_library',
						__( 'External links', 'vc_extend' ) => 'external_link',
					),
					'std' => 'media_library',
					'description' => __( 'Select image source.', 'vc_extend' ),
				),
				array(
					'type' => 'attach_images',
					'heading' => __( 'Images', 'vc_extend' ),
					'param_name' => 'images',
					'value' => '',
					'description' => __( 'Select images from media library.', 'vc_extend' ),
					'dependency' => array(
						'element' => 'source',
						'value' => 'media_library',
					),
				),
				array(
					'type' => 'exploded_textarea_safe',
					'heading' => __( 'External links', 'vc_extend' ),
					'param_name' => 'custom_srcs',
					'description' => __( 'Enter external link for each gallery image (Note: divide links with linebreaks (Enter)).', 'vc_extend' ),
					'dependency' => array(
						'element' => 'source',
						'value' => 'external_link',
					),
				),
				array(
					'type' => 'textfield',
					'heading' => __( 'Image size', 'vc_extend' ),
					'param_name' => 'img_size',
					'value' => 'thumbnail',
					'description' => __( 'Enter image size. Example: thumbnail, medium, large, full or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use "thumbnail" size.', 'vc_extend' ),
					'dependency' => array(
						'element' => 'source',
						'value' => 'media_library',
					),
				),
				array(
					'type' => 'textfield',
					'heading' => __( 'Image size', 'vc_extend' ),
					'param_name' => 'external_img_size',
					'value' => '',
					'description' => __( 'Enter image size in pixels. Example: 200x100 (Width x Height).', 'vc_extend' ),
					'dependency' => array(
						'element' => 'source',
						'value' => 'external_link',
					),
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'On click action', 'vc_extend' ),
					'param_name' => 'onclick',
					'value' => array(
						__( 'None', 'vc_extend' ) => '',
						__( 'Link to large image', 'vc_extend' ) => 'img_link_large',
						__( 'Open prettyPhoto', 'vc_extend' ) => 'link_image',
						__( 'Open custom link', 'vc_extend' ) => 'custom_link',
					),
					'description' => __( 'Select action for click action.', 'vc_extend' ),
					'std' => 'link_image',
				),
				array(
					'type' => 'exploded_textarea_safe',
					'heading' => __( 'Custom links', 'vc_extend' ),
					'param_name' => 'custom_links',
					'description' => __( 'Enter links for each slide (Note: divide links with linebreaks (Enter)).', 'vc_extend' ),
					'dependency' => array(
						'element' => 'onclick',
						'value' => array( 'custom_link' ),
					),
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Custom link target', 'vc_extend' ),
					'param_name' => 'custom_links_target',
					'description' => __( 'Select where to open  custom links.', 'vc_extend' ),
					'dependency' => array(
						'element' => 'onclick',
						'value' => array(
							'custom_link',
							'img_link_large',
						),
					),
					'value' => vc_target_param_list(),
				),
				vc_map_add_css_animation(),
				array(
					'type' => 'el_id',
					'heading' => __( 'Element ID', 'vc_extend' ),
					'param_name' => 'el_id',
					'description' => sprintf( __( 'Enter element ID (Note: make sure it is unique and valid according to <a href="%s" target="_blank">w3c specification</a>).', 'vc_extend' ), 'http://www.w3schools.com/tags/att_global_id.asp' ),
				),
				array(
					'type' => 'textfield',
					'heading' => __( 'Extra class name', 'vc_extend' ),
					'param_name' => 'el_class',
					'description' => __( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'vc_extend' ),
				),
				array(
					'type' => 'css_editor',
					'heading' => __( 'CSS box', 'vc_extend' ),
					'param_name' => 'css',
					'group' => __( 'Design Options', 'vc_extend' ),
				),
			),
		));



		vc_map( array(
            "name" => __("Alvaro Blog List", 'vc_extend'),
            "description" => __("Alvaro Blog List", 'vc_extend'),
            "base" => "vc_alvaro_blog_list",
            "class" => "",
            "controls" => "full",
            "icon" => plugins_url('assets/images/icons/alvaro_icon.png', __FILE__), // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
            "category" => __('Alvaro', 'vc_extend'),
            //'admin_enqueue_js' => array(plugins_url('assets/vc_extend.js', __FILE__)), // This will load js file in the VC backend editor
            //'admin_enqueue_css' => array(plugins_url('assets/vc_extend_admin.css', __FILE__)), // This will load css file in the VC backend editor
            "params" => array(
              array(
			      "type"        => "dropdown",
			      "heading"     => __("Blog columns number"),
			      "param_name"  => "blog_columms_no",
			      "admin_label" => true,
			      "value"       => array(
			        '1 column'   => '1',
			        '2 columns'   => '2'
			      ),
			      "std"         => '1',
			      "description" => __("Blog columns number")
		      ),
			  
              array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Blog posts per page", 'vc_extend'),
                  "param_name" => "per_page",
                  "value" => __("", 'vc_extend'),
                  "std"         => '10',
                  "description" => __("Blog posts per page", 'vc_extend')
              ),
              
			  array(
			      "type"        => "dropdown",
			      "heading"     => __("Order Blog Posts By"),
			      "param_name"  => "orderby",
			      "admin_label" => true,
			      "value"       => array(
				        'post_date'   => 'post_date',
				        'ID'   => 'ID',
				        'author'   => 'author',
				        'title'   => 'title',
				        'name'   => 'name',
				        'menu_order'   => 'menu_order',
			      ),
			      "std"         => 'post_date',
			      "description" => __("")
		      ),
		      
            )
        ) );


		vc_map( array(
            "name" => __("Shop Title Preview", 'vc_extend'),
            "description" => __("Alvaro Shop Title Preview", 'vc_extend'),
            "base" => "vc_alvaro_shop_title_preview",
            "class" => "",
            "controls" => "full",
            "icon" => plugins_url('assets/images/icons/alvaro_icon.png', __FILE__), // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
            "category" => __('Alvaro', 'vc_extend'),
            //'admin_enqueue_js' => array(plugins_url('assets/vc_extend.js', __FILE__)), // This will load js file in the VC backend editor
            //'admin_enqueue_css' => array(plugins_url('assets/vc_extend_admin.css', __FILE__)), // This will load css file in the VC backend editor
            "params" => array(
			  
              array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("Title", 'vc_extend'),
                  "param_name" => "st_preview_title",
                  "value" => __("", 'vc_extend'),
                  "std"         => 'Our Store',
                  "description" => __("Shop Preview Title", 'vc_extend')
              ),
              
              array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("URL", 'vc_extend'),
                  "param_name" => "st_preview_url",
                  "value" => __("", 'vc_extend'),
                  "std"         => 'Our Store',
                  "description" => __("Shop Preview URL", 'vc_extend')
              ),

              array(
                  "type" => "textfield",
                  "holder" => "",
                  "class" => "",
                  "heading" => __("URL Name", 'vc_extend'),
                  "param_name" => "st_preview_url_name",
                  "value" => __("", 'vc_extend'),
                  "std"         => 'Visit Our Store',
                  "description" => __("Shop Preview URL Name", 'vc_extend')
              ),              
		      
            )
        ) );

				
    }

	/**
	 * @param $el_class
	 *
	 * @return string
	 */
	public function getExtraClass( $el_class ) {
		$output = '';
		if ( '' !== $el_class ) {
			$output = ' ' . str_replace( '.', '', $el_class );
		}

		return $output;
	}

	/**
	 * @param $css_animation
	 *
	 * @return string
	 */
	public function getCSSAnimation( $css_animation ) {
		$output = '';
		if ( '' !== $css_animation && 'none' !== $css_animation ) {
			wp_enqueue_script( 'waypoints' );
			wp_enqueue_style( 'animate-css' );
			$output = ' wpb_animate_when_almost_visible wpb_' . $css_animation . ' ' . $css_animation;
		}

		return $output;
	}

	/**
	 * @return mixed
	 */
	public function getShortcode() {
		return $this->shortcode;
	}
	
	public function alvaro_custom_gallery( $atts, $content = null )
	{
		/**
		 * Shortcode attributes
		 * @var $atts
		 * @var $title
		 * @var $source
		 * @var $type
		 * @var $onclick
		 * @var $has_thumb_nav_slider
		 * @var $custom_links
		 * @var $custom_links_target
		 * @var $img_size
		 * @var $external_img_size
		 * @var $images
		 * @var $custom_srcs
		 * @var $el_class
		 * @var $el_id
		 * @var $interval
		 * @var $css
		 * @var $css_animation
		 * Shortcode class
		 * @var $this WPBakeryShortCode_VC_gallery
		 */
		 
		$thumbnail = '';
		$title = $gallery_height = $bg_color = $border_size = $prev_next_buttons = $fullscreen_toggle = $source = $onclick = $has_thumb_nav_slider = $custom_links = $custom_links_target = $img_size = $external_img_size = $images = $custom_srcs = $el_class = $el_id = $interval = $stop_on_hover = $css = $css_animation = '';
		$large_img_src = '';
		
		#$attributes = vc_map_get_attributes( 'vc_gallery', $atts );
		#extract( $atts );
		
		extract( shortcode_atts( array(
			'title'					=> '',
			'gallery_height'		=> '380px',
			'bg_color'				=> '#101f3e',
			'border_size' 			=> '20',
			'prev_next_buttons'		=> 'yes',
			'fullscreen_toggle'		=> 'yes',
			'source'				=> 'media_library',
			//'type' 					=> 'fading',
			'onclick'			 	=> 'link_image',
			'has_thumb_nav_slider'	=> 'yes',
			'interval'				=> 3,
			'stop_on_hover'			=> 'yes',
			'custom_links' 			=> '',
			'custom_links_target' 	=> '_self',
			'img_size' 				=> 'thumbnail',
			'external_img_size' 	=> '',
			'images' 				=> '',
			'custom_srcs' 			=> '',
			'el_class' 				=> '',
			'el_id' 				=> '',
			'css' 					=> '',
			'css_animation' 		=> '',
		), $atts ) );
		
		$default_src = vc_asset_url( 'vc/no_image.png' );
		
		$gal_images = '';
		$gal_thumb_images = '';
		$link_start = '';
		$link_end = '';
		$el_start = '';
		$el_end = '';
		$slides_wrap_start = '';
		$slides_wrap_end = '';
		
		$el_class = $this->getExtraClass( $el_class );
		
		//wp_enqueue_style( 'vc_pgwslider_theme' );
		wp_enqueue_script( 'vc_aatslideshow_js' );
		
		$el_start = '<li>';
		$el_end = '</li>';
		$slides_wrap_start = '<ul id="species-gallery">';
		$slides_wrap_end = '</ul>';
		
		if ( 'link_image' === $onclick ) {
			wp_enqueue_script( 'prettyphoto' );
			wp_enqueue_style( 'prettyphoto' );
		}
		
		if ( '' === $images ) {
			$images = '-1,-2,-3';
		}
		
		$pretty_rel_random = ' data-rel="prettyPhoto[rel-' . get_the_ID() . '-' . rand() . ']"';
		
		if ( 'custom_link' === $onclick ) {
			$custom_links = vc_value_from_safe( $custom_links );
			$custom_links = explode( ',', $custom_links );
		}
		
		switch ( $source ) {
			case 'media_library':
				$images = explode( ',', $images );
				break;
		
			case 'external_link':
				$images = vc_value_from_safe( $custom_srcs );
				$images = explode( ',', $images );
		
				break;
		}
		  
		foreach ( $images as $i => $image ) {
			switch ( $source ) {
				case 'media_library':
					if ( $image > 0 ) {
						$img = wpb_getImageBySize( array(
							'attach_id' => $image,
							'thumb_size' => $img_size,
						) ); 
						$thumbnail = $img['thumbnail'];
						$large_img_src = $img['p_img_large'][0];
					} else {
						$large_img_src = $default_src;
						$thumbnail = '<img src="' . $default_src . '" />';
					}
					break;
		
				case 'external_link':
					$image = esc_attr( $image );
					$dimensions = vcExtractDimensions( $external_img_size );
					$hwstring = $dimensions ? image_hwstring( $dimensions[0], $dimensions[1] ) : '';
					$thumbnail = '<img ' . $hwstring . ' src="' . $image . '" />';
					$large_img_src = $image;
					break;
			}
		
			$link_start = $link_end = '';
			
			
			switch ( $onclick ) {
				case 'img_link_large':
					$link_start = '<a href="' . $large_img_src . '" target="' . $custom_links_target . '">';
					$link_end = '</a>';
					break;
		
				case 'link_image':
					$link_start = '<a class="prettyphoto" href="' . $large_img_src . '"' . $pretty_rel_random . '>';
					$link_end = '</a>';
					break;
		
				case 'custom_link':
					if ( ! empty( $custom_links[ $i ] ) ) {
						$link_start = '<a href="' . $custom_links[ $i ] . '"' . ( ! empty( $custom_links_target ) ? ' target="' . $custom_links_target . '"' : '' ) . '>';
						$link_end = '</a>';
					}
					break;
			}
		
			$gal_images .= $el_start . $link_start . $thumbnail . $link_end . $el_end;
			
			if( $has_thumb_nav_slider == 'yes' ) {
				$gal_thumb_images .= $el_start . $thumbnail . $el_end;
			}
		}
		
		$class_to_filter = 'wpb_content_element vc_clearfix';
		$class_to_filter .= vc_shortcode_custom_css_class( $css, ' ' ) . $this->getExtraClass( $el_class ) . $this->getCSSAnimation( $css_animation );
		$css_class = apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, $class_to_filter, 'vc_alvaro_gallery', $atts );
		$wrapper_attributes = array();
		if ( ! empty( $el_id ) ) {
			$wrapper_attributes[] = 'id="' . esc_attr( $el_id ) . '"';
		}
		
		$html[] = '<div class="' . $css_class . '" ' . implode( ' ', $wrapper_attributes ) . '>';
		$html[] = '<div class="wpb_wrapper">';
		$html[] = wpb_widget_title( array(
			'title' => $title,
			'extraclass' => 'wpb_gallery_heading',
		) );
		
		$html[] = '<div class="aat-slideshow aat-slideshow-fullscreen" data-height="' . $gallery_height . '" data-interval="' . $interval . '" data-stop_on_hover="' . $stop_on_hover . '" data-show_thumbs="' . ( $has_thumb_nav_slider ) . '" style="background-color:' . ( $bg_color ) . '; padding:' . ( $border_size ) . 'px; height:' . ( $gallery_height ) . ';">';
		$html[] = 	'<div class="aat-slideshow-wrapper">';
		
		if( $has_thumb_nav_slider == 'yes' ) {
			$html[] = 		'<div class="aat-slideshow-thumbnails-nav">';
			$html[] = 			'<div class="aat-slideshow-thumbnails-wrapper">';
			$html[] = 				'<ul class="aat-slideshow-thumbnails">';
			$html[] = 					$gal_thumb_images;
			$html[] = 				'</ul>';
			$html[] = 			'</div>';
			$html[] = 		'</div>';
		}

		if( $prev_next_buttons == 'yes' ) {
			$html[] = 		'<div class="aat-slideshow-header-nav">';
			$html[] = 			'<a href="#prev" class="aat-slideshow-header-prev"><i class="moonicon icon icon-arrow-left2"></i></a>';
			$html[] = 			'<a href="#next" class="aat-slideshow-header-next"><i class="moonicon icon icon-arrow-right2"></i></a>';
			$html[] = 		'</div>';
		}
		
		if( $fullscreen_toggle == 'yes' ) {
			$html[] = 		'<a href="#full-screen" class="aat-slideshow-btn-fullscreen-mode aat-slideshow-enter-fullscreen"><i class="moonicon icon icon-enlarge7"></i></a>';
			$html[] = 		'<a href="#full-screen" class="aat-slideshow-btn-fullscreen-mode aat-slideshow-exit-fullscreen"><i class="moonicon icon icon-cross"></i></a>';
		}
		
		$html[] = 		'<div class="aat-slideshow-main-images-wrapper">';
		$html[] = 			'<ul class="aat-slideshow-main-images">';
		$html[] = 				$gal_images;
		$html[] = 			'</ul>';
		$html[] = 		'</div>';
		$html[] = 	'</div>';
		$html[] = '</div>';
		
		$html[] = '</div>';
		$html[] = '</div>';
		
		return implode("\n", $html);
		
	}

	/* Alvaro Fancy heading */
	public function alvaro_fancy_heading( $atts, $content = null )
	{
		extract( shortcode_atts( array(
			'fancy_heading_icon'	=> 'no',
			'fancy_heading_style'	=> 'Style 1',
			'fancy_heading_icon_type' => 'font awesome',
			'font_awesome_icon' => 'fa fa-asterisk',
			'ico_moon_icon' => 'moonicon icon icon-home',
			'icon_url' => '',
			'title' => 'Fish Species',
			'text_align' => 'center',
			'color' => '#282828',
			'font_size' => '',
			'line_width' => ''
		), $atts ) );
		$icon_img = '';
		$fa_icon = '';
		$icomoon_icon = '';

		/* Check if line_width isset and if not, set 80 as default */
		if ($line_width == "") {
			$line_width = 80;
		}

		/* Check if color isset and if not, set #282828 as default */
		if ($color == "") {
			$color = '#282828';
		}

		if( $fancy_heading_icon == 'yes' ) {
			if( $fancy_heading_icon_type == 'manual uploads' ) {
				if( isset( $icon_url ) ) {
					$icon = wp_get_attachment_image_src( $icon_url, "full" );
		        	$icon = $icon[0];
					$icon_img = '<p class="fancy-heading-icon"><span style="width: ' . $line_width . '%;"></span><img src="'. $icon .'" alt="'. $title .'" /></p>';
				}
			} elseif( $fancy_heading_icon_type == 'font awesome' ) {
				if( isset( $font_awesome_icon ) ) {
					$fa_icon = '<p class="fancy-heading-icon"><span style="width: ' . $line_width . '%;"></span><i class="' . $font_awesome_icon . '"></i></p>';
				}
			} elseif( $fancy_heading_icon_type == 'icomoon' ) {
				if( isset( $ico_moon_icon ) ) {
					$icomoon_icon = '<p class="fancy-heading-icon"><span style="width: ' . $line_width . '%;"></span><i class="' . $ico_moon_icon . '"></i></p>';
				}
			}
		}

		if( $fancy_heading_style == 'Style 1' ) {
			$fancy_heading_style_class = 'style-1';
		} elseif( $fancy_heading_style == 'Style 2' ) {
			$fancy_heading_style_class = 'style-2';
		}
		
		$fss = '';
		
		if( isset( $font_size ) && $font_size != '' ) {
			$fss = ' font-size: ' . $font_size . 'px; ';
		}

		return $icon_img . $fa_icon . $icomoon_icon . '<h3 style="' . $fss . ' text-align: ' . $text_align . '; color: ' . $color . ';" class="alvaro-fancy-heading ' . $fancy_heading_style_class . '">' . $title . '</h3>';
	}
	
	/* Alvaro Section heading */
	public function alvaro_section_heading( $atts, $content = null )
	{
		extract( shortcode_atts( array(
			'title' => 'Lorem Ipsum',
			'text_align' => 'left',
		), $atts ) );

		if ($text_align != 'left') {
			$padding = 'style="padding-left: 25px; padding-right: 25px;"';
		} else {
			$padding = '';
		}
		return '<div class="alvaro-section-heading" style="text-align:' . $text_align . ';"><h4 ' . $padding . '>' . $title . '</h4></div>';
	}
	
	/* Alvaro Custom Title Preview */
	public function alvaro_shop_title_preview( $atts, $content = null )
	{
		extract( shortcode_atts( array(
			'st_preview_title' => 'Our Store',
			'st_preview_url' => '#',
			'st_preview_url_name' => 'Visit Our Store',
		), $atts ) );

		
		$html = array();

		$html[] = '<div class="alvaro-shop-title-preview">';

			if ( $st_preview_title ) {
				$html[] = '<h3>' . $st_preview_title . '</h3>';
			}
			
			if ( $st_preview_title || $st_preview_url ) {
				$html[] = '<div class="alvaro-shop-title-preview-line"></div>';
			}

			if ( $st_preview_url ) {
				$html[] = '<a href="'. esc_url( $st_preview_url ) .'" class="alvaro-shop-preview-url">' . $st_preview_url_name . '</h3>';
			}

		$html[] = '</div>';

		return implode("\n", $html);

	}


	public function alvaro_image_hotspot( $atts, $content = null ) {
		extract( shortcode_atts( array(
			'hotspot_image_url' => '',
			'hotspot_intro_title' => 'fishing trip',
			'hotspot_title' => 'Danube',
			'hotspot_subtitle' => '8 days / 7 nights',
			'hotspot_coin' => '$',
			'hotspot_price' => '499.99',
			'hotspot_viewmore_link' => '#',
		), $atts ) );
		
		if( isset( $hotspot_image_url ) ) {
			$html = array();
			$hotspot_image = wp_get_attachment_image_src( $hotspot_image_url, "full" );
        	$hotspot_image = $hotspot_image[0];
			
			$html[] = '<div class="alvaro_hotspot_outer_wrapper_top"></div>';
				$html[] = '<div class="alvaro_hotspot_wrapper">';
					$html[] = '<div class="alvaro_hotspot_content_wrapper">';
						$html[] = '<h3 class="alvaro_hotspot_intro_title">' . $hotspot_intro_title . '</h3>';
						$html[] = '<h3 class="alvaro_hotspot_title_big">' . $hotspot_title . '</h3>';
						$html[] = '<h4 class="alvaro_hotspot_subtitle_big">' . $hotspot_subtitle . '</h4>';
						$html[] = '<div class="alvaro_hotspot_content">' . $content . '</div>';
					$html[] = '</div>';
					$html[] = '<div class="alvaro_hotspot">';
						$html[] = '<img src="'. $hotspot_image .'" alt="'. $hotspot_title .'" />';
					$html[] = '</div>';
					
					$html[] = '<div class="alvaro_hotspot_price_wrapper">';
						$html[] = '<p class="alvaro_hotspot_starting_at">' . __('Starting From', 'alvaro') . '</p>';
						$html[] = '<p class="alvaro_hotspot_price"><span>' . $hotspot_coin . '</span>' . $hotspot_price . '</p>';
						$html[] = '<a href="' . $hotspot_viewmore_link . '" class="alvaro_hotspot_viewmore">' . __('View More', 'alvaro') . '</a>';
					$html[] = '</div>';
					
				$html[] = '</div>';
			$html[] = '<div class="alvaro_hotspot_outer_wrapper_bottom"></div>';
			$hotspots = vc_param_group_parse_atts( $atts['hotspots'] );
			if( isset( $hotspots ) && count( $hotspots ) > 0 ) {
				$html[] = '
				<script type="text/javascript">
					jQuery(".alvaro_hotspot").hotspot({
						data: [ ';
				foreach( $hotspots as $hotspot ) {
					 
					if( isset($hotspot['hotspot_icon']) && isset($hotspot['hotspot_image']) && isset($hotspot['hotspot_x']) && isset($hotspot['hotspot_y']) && isset($hotspot['hotspot_title']) ) {
						$hotspot_icon = wp_get_attachment_image_src( $hotspot["hotspot_icon"], "full" );
			        	$hotspot_icon = $hotspot_icon[0];
						
						$hotspot_image = wp_get_attachment_image_src( $hotspot["hotspot_image"], "full" );
			        	$hotspot_image = $hotspot_image[0];
						
						$html[] = '	{ "x":' . $hotspot['hotspot_x'] . ', "y":' . $hotspot['hotspot_y'] . ', "Icon":"<img class=\"alvaro_hotspot_icon\" src=\"' . $hotspot_icon . '\" alt=\"\" />", "Title":"<p class=\"alvaro_hotspot_title\">' . $hotspot['hotspot_title'] . '</p>","Message":"<img class=\"alvaro_hotspot_image\" src=\"' . $hotspot_image .'\" alt=\"\" />" }, ';
					}
				}
				$html[] = '			
						],
						interactivity: "click",
					});
				</script>
				';
			}
			
			return implode("\n", $html);
			
		}
		
	}

	public function alvaro_fish_species_slider( $atts, $content )
	{
		global $post;

		$html = array();

		extract( shortcode_atts( array(
			'per_page' 	=> '10',
			'orderby' => 'post_date',
			'order'	  => 'DESC',
			'autoplay' => 'false',
			'items' => '3',
			'items_desktop' => '3',
			'items_desktop_small' => '1',
			'items_tablet' => '1',
			'items_mobile' => '1',
			'pagination' => 'true',
			'navigation' => 'true'
		), $atts ) );

		$fish_species_args = array(
			'post_type' => 'fish_species',
			'posts_per_page' => (int)$per_page,
			'orderby' => $orderby,
			'order'	  => $order,
		);
		 
		$html = array();
		$html[] = '<div class="alvaro-fish-species-list alvaro-species-slider-shortcode" data-autoplay="' . $autoplay . '" data-items="' . $items . '" data-items_desktop="' . $items_desktop . '" data-items_desktop_small="' . $items_desktop_small . '" data-items_tablet="' . $items_tablet . '" data-items_mobile="' . $items_mobile . '">';
							$fish_species_query = new WP_Query( $fish_species_args );
							while ( $fish_species_query->have_posts() ) : $fish_species_query->the_post();								
							$thumbnail_url = wp_get_attachment_url( get_post_thumbnail_id($post->ID), 'full' );
						$html[] = '<div class="alvaro-species-slide">';	
							$html[] = '<div class="alvaro-fish-image-wrap">';
								$html[] = '<a href="' . ( get_permalink() ) . '"><img class="alvaro-fish-image" src="' . $thumbnail_url .'" alt="' . get_the_title() . '" /></a>';
							$html[] = '</div>';

							$html[] = '<div class="alvaro-border-default"></div>';
							$html[] = '<div class="alvaro-border-hover"></div>';

							$html[] = '<p class="alvaro-fish-title"><a href="' . ( get_permalink() ) . '">' . get_the_title() . '</a></p>';
							$html[] = '<p class="alvaro-fish-intro">' . get_the_excerpt() . '</p>';
						$html[] = '</div>';
					endwhile;
					wp_reset_postdata();
				$html[] = '</div>';

		return implode("\n", $html);
	}

	public function alvaro_camping_locations_slider( $atts, $content )
	{
		global $post;

		$html = array();

		extract( shortcode_atts( array(
			'per_page' 	=> '10',
			'orderby' => 'post_date',
			'order'	  => 'DESC',

			'autoplay' => 'false',
			'items' => '3',
			'items_desktop' => '3',
			'items_desktop_small' => '1',
			'items_tablet' => '1',
			'items_mobile' => '1',
			'pagination' => 'true',
			'navigation' => 'true'
		), $atts ) );

		$camping_locations_args = array(
			'post_type' => 'camping_location',
			'posts_per_page' => (int)$per_page,
			'orderby' => $orderby,
			'order'	  => $order,
		);

		$fish_icon_src = plugins_url( 'assets/images/icons/fish_icon.png', __FILE__ );

		$html = array();
		$html[] = '<div class="alvaro-camping-locations-list alvaro-camping-locations-slider-shortcode" data-autoplay="' . $autoplay . '" data-items="' . $items . '" data-items_desktop="' . $items_desktop . '" data-items_desktop_small="' . $items_desktop_small . '" data-items_tablet="' . $items_tablet . '" data-items_mobile="' . $items_mobile . '">';
						$camping_locations_query = new WP_Query( $camping_locations_args );
						while ( $camping_locations_query->have_posts() ) : $camping_locations_query->the_post();								
						$thumbnail = wp_get_attachment_image( get_post_thumbnail_id($post->ID), 'alvaro-camping-locations' );
							$html[] = '<div class="alvaro-camping-locations-slide">';

								$html[] = '<div class="alvaro-fish-image-wrap">';

									$html[] = '<a href="' . get_permalink() . '"><span class="alvaro-fish-image-gradient"></span></a>';
									$html[] = '<a href="' . get_permalink() . '">' . $thumbnail . '</a>';


									$html[] = '<div class="alvaro-camping-content-wrapper">';

										/* Google Map */
										$gmap_iframe = get_field( 'google_maps_embed_code' );
										
										if( isset( $gmap_iframe ) && $gmap_iframe != '' ) {  
											$html[] = '<a href="#" data-camping-map=\'' . ( json_encode($gmap_iframe) ) . '\' class="alvaro-camping-location-pin"><i class="moonicon icon icon-location4"></i></a>';
										}
										
										/* Camping Title */
										$html[] = '<a href="' . get_permalink() . '" class="alvaro-camping-title">' . get_the_title() . '</a>';

										
										/* Fish Icon & Fish Species */
										$pplfhf_species = get_field('people_fish_here_for');
										$fishes = array();
										  
										if( is_array($pplfhf_species) && count( $pplfhf_species ) > 0 ) {
											foreach( $pplfhf_species as $fish ) {
												if( isset($fish->ID) && isset($fish->post_title) ) {
													$fishes[] = '<a href="' . get_permalink( $fish->ID ) . '">' . strtolower( $fish->post_title ) . '</a>';
												}
											}
										}
										
										$html[] = '<div class="alvaro-camping-info">';

											$html[] = '<img src="' . $fish_icon_src . '" alt="' . __('People fish here for:', 'alvaro') . '" class="alvaro-pplfhf-fish-icon" />';

											$html[] = '<p class="alvaro-pplfhf-list">' . implode(', ', $fishes) . '</p>';

										$html[] = '</div>';


									$html[] = '</div>'; /* end of .alvaro-camping-content-wrapper */

								$html[] = '</div>'; /* end of .alvaro-fish-image-wrap */

							$html[] = '</div>';
						endwhile;
						wp_reset_postdata();
				$html[] = '</div>';

		return implode("\n", $html);
	}
	
	public function alvaro_camping_locations_list( $atts, $content )
	{
		global $post;

		$html = array();

		extract( shortcode_atts( array(
			'per_page' 	=> '10',
			'orderby' => 'post_date',
			'order'	  => 'DESC',
		), $atts ) );

		$camping_locations_args = array(
			'post_type' => 'camping_location',
			'posts_per_page' => (int)$per_page,
			'orderby' => $orderby,
			'order'	  => $order,
		);

		$fish_icon_src = plugins_url( 'assets/images/icons/fish_icon.png', __FILE__ );

		$html = array();
		$html[] = '<div class="alvaro-camping-locations-list row">';
			$html[] = '<div>';
							$camping_locations_query = new WP_Query( $camping_locations_args );
							while ( $camping_locations_query->have_posts() ) : $camping_locations_query->the_post();								
							$thumbnail = wp_get_attachment_image( get_post_thumbnail_id($post->ID), 'alvaro-camping-locations' );
						
							$html[] = '<div class="alvaro-camping-locations col-md-4 col-sm-6">';
								$html[] = '<div class="alvaro-fish-image-wrap">';
									$html[] = '<a href="' . get_permalink() . '"><span class="alvaro-fish-image-gradient"></span></a>';
									$html[] = '<a href="' . get_permalink() . '">' . $thumbnail . '</a>';


									$html[] = '<div class="alvaro-camping-content-wrapper">';


										/* Google Map */
										$gmap_iframe = get_field( 'google_maps_embed_code' );
										
										if( isset( $gmap_iframe ) && $gmap_iframe != '' ) {  
											$html[] = '<a href="#" data-camping-map=\'' . ( json_encode($gmap_iframe) ) . '\' class="alvaro-camping-location-pin"><i class="moonicon icon icon-location4"></i></a>';
										}
										
										/* Camping Title */
										$html[] = '<a href="' . get_permalink() . '" class="alvaro-camping-title">' . get_the_title() . '</a>';

										
										/* Fish Icon & Fish Species */
										$pplfhf_species = get_field('people_fish_here_for');
										$fishes = array();
										  
										if( is_array($pplfhf_species) && count( $pplfhf_species ) > 0 ) {
											foreach( $pplfhf_species as $fish ) {
												if( isset($fish->ID) && isset($fish->post_title) ) {
													$fishes[] = '<a href="' . get_permalink( $fish->ID ) . '">' . strtolower( $fish->post_title ) . '</a>';
												}
											}
										}
										
										$html[] = '<div class="alvaro-camping-info">';

											$html[] = '<img src="' . $fish_icon_src . '" alt="' . __('People fish here for:', 'alvaro') . '" class="alvaro-pplfhf-fish-icon" />';

											$html[] = '<p class="alvaro-pplfhf-list">' . implode(', ', $fishes) . '</p>';

										$html[] = '</div>';


									$html[] = '</div>';


								$html[] = '</div>';



								//$html[] = '<a href="' . get_permalink() . '" class="alvaro-camping-view-more-button">' . __('View Details', 'alvaro') . '</a>';
								
							$html[] = '</div>';
					endwhile;
					wp_reset_postdata();
					$html[] = '</div>';
				$html[] = '</div>';

		return implode("\n", $html);
	}
	
	public function alvaro_blog_list( $atts, $content )
	{	
		$html = array();
			
		extract( shortcode_atts( array(
			'per_page' 	=> '10',
			'orderby' => 'post_date',
			'blog_columms_no' => 1
		), $atts ) );
		
		$args = array(
		    'numberposts' => (int)$per_page,
		    'orderby' => 'post_date',
		    'order' => 'DESC',
		    'post_type' => 'post',
		    'post_status' => 'publish',
		    'suppress_filters' => true 
		);
	
	    $recent_posts = wp_get_recent_posts( $args, ARRAY_A );
		if( count($recent_posts) > 0 ){
			$item_bs_class = '';
			if( $blog_columms_no == 1 ) {
				$item_bs_class = ' col-lg-12 ';
			} elseif(  $blog_columms_no == 2 ) {
				$item_bs_class = ' col-lg-6 col-md-6 col-sm-12 col-xs-12 ';
			}
			
			$html[] = '<div id="alvaro_blog_list">';
				$html[] = '<div class="row">'; /* start of row */
					foreach ($recent_posts as $post) {
						
						$post_link = get_permalink( $post['ID'] );
						$post_thumbnail_id = get_post_thumbnail_id( $post['ID'] );
						$thumb = wp_get_attachment_image_src( $post_thumbnail_id, array(400,400) );
						
						$html[] = '<div class="alvaro-blog-item ' . $item_bs_class . '">';
							$html[] = '<div class="row">';
							if( $thumb == false ) {
								$html[] = 	'<div class="col-lg-12">';
									$html[] = '<p class="alvaro_blog_list_date">' . get_the_date( null, $post['ID'] ) . '</p>';
									$html[] = '<h2><a href="' . ( $post_link ) . '">' . ( $post['post_title'] ) . '</a></h2>';
									$html[] = '<p class="alvaro_blog_list_comments"><i class="mi-icon mi-icon-bubble2"></i>' . get_comments_number( $post['ID'] ) . '</p>';
								$html[] =   '</div>';
							} else {
								$html[] = 	'<div class="col-lg-5">';
									$html[] = '<p class="alvaro_blog_list_date">' . get_the_date( null, $post['ID'] ) . '</p>';
									$html[] = '<h2><a href="' . ( $post_link ) . '">' . ( $post['post_title'] ) . '</a></h2>';
									$html[] = '<p class="alvaro_blog_list_comments"><i class="mi-icon mi-icon-bubble2"></i>' . get_comments_number( $post['ID'] ) . '</p>';
								$html[] =   '</div>';
								
								$html[] = 	'<div class="col-lg-7">';
									$html[] = '<div class="alvaro_blog_list_img">';
										$html[] = 		'<a href="' . ( $post_link ) . '"><span style="background-image:url(' . ( $thumb[0] ) . ');"></span></a>';
									$html[] = '</div>';
								$html[] = '</div>';
							}
							$html[] = '</div>';
						$html[] = '</div>';
						
					}
				$html[] = '</div>'; /* end of row */
			$html[] = '</div>';
		}
		
		return implode("\n", $html);
	}

	public function alvaro_google_maps( $atts, $content )
	{
		extract( shortcode_atts( array(
			'address' 	=> '',
			'zoom'		=> 12,
			'hide_controls' => 'true',
			'black_and_white' => 'true',
			'marker'	=> '',
			'height'	=> '400px',
			'width'		=> '100%',
			'api_key'	=> '',
		), $atts ) ); 
		 
		if( isset($api_key) && trim($api_key) != '' ) {
			wp_enqueue_script( 'google-maps', '//maps.google.com/maps/api/js?key=' . ( $api_key ), array('jquery', 'vc_extend_js'), '2.0', true);
		
			if( isset($marker) && $marker > 0 ) {
				$marker = wp_get_attachment_url( $marker );
			}
			
			$content = str_replace( array( '<p></p>', '<p>  </p>', '<br />', '<br>' ), '', $content );
			$html[] = '<div class="alvaro-map" id="alvaro-map" style="width:'.$width.'; height:'.$height.';" data-address="'.$address.'"  data-zoom="'.$zoom.'" data-marker="'.$marker.'" data-hide_controls="'.$hide_controls.'" data-black_and_white="'.$black_and_white.'"></div>';
			
			return implode("\n", $html);
		}
	}




    /*
    Load plugin css and javascript files which you may need on front end of your site
    */
    public function loadCssAndJs() {
      wp_register_style( 'vc_extend_style', plugins_url('assets/vc_extend.css', __FILE__) );
      wp_enqueue_style( 'vc_extend_style' );
	  
	  // frontend moon icon
	  wp_register_style( 'vc-icomoon', plugins_url('assets/icomoon.css', __FILE__) );
	  wp_register_style( 'vc-owl_carousel', plugins_url('assets/owl.carousel.css', __FILE__) );
	  wp_register_style( 'vc-owl_theme', plugins_url('assets/owl.theme.css', __FILE__) );
	  wp_register_style( 'vc-jquery-hotspot', plugins_url('assets/jquery.hotspot.css', __FILE__) );
	  wp_enqueue_style( 'vc-icomoon' );
	  wp_enqueue_style( 'vc-owl_carousel' );
	  wp_enqueue_style( 'vc-owl_theme' );
	  wp_enqueue_style( 'vc-jquery-hotspot' );
	  //wp_register_style( 'vc_pgwslider_theme', plugins_url('assets/pgwslider.css', __FILE__) );
		
		
      // If you need any javascript files on front end, here is how you can load them.
      //wp_register_script( 'vc_pgwslider_js', plugins_url('assets/pgwslider.min.js', __FILE__), array('jquery') );
      wp_register_script( 'vc_aatslideshow_js', plugins_url('assets/slideshow.js', __FILE__), array('jquery') );
      wp_enqueue_script( 'vc_owl_js', plugins_url('assets/owl.carousel.min.js', __FILE__), array('jquery') );
	  wp_enqueue_script( 'vc_hotspot_js', plugins_url('assets/jquery.hotspot.js', __FILE__), array('jquery') );
      wp_enqueue_script( 'vc_extend_js', plugins_url('assets/vc_extend.js', __FILE__), array('jquery', 'vc_aatslideshow_js') );
    }

    /*
    Show notice if your plugin is activated but Visual Composer is not
    */
    public function showVcVersionNotice() {
        $plugin_data = get_plugin_data(__FILE__);
        echo '
        <div class="updated">
          <p>'.sprintf(__('<strong>%s</strong> requires <strong><a href="http://bit.ly/vcomposer" target="_blank">Visual Composer</a></strong> plugin to be installed and activated on your site.', 'vc_extend'), $plugin_data['Name']).'</p>
        </div>';
    }

}
// Finally initialize code
new VCExtendAddonClass();